package com.chinaitop;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import com.google.common.base.Function;
import com.google.common.base.Optional;
import com.google.common.base.Predicate;

import springfox.documentation.RequestHandler;
import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.builders.RequestHandlerSelectors;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

@Configuration
@EnableSwagger2
public class SwaggerConfig {

	@Value("${eureka.instance.hostname}")
	private String eureka_ip;

	// 定义分隔符,配置Swagger多包
    private static final String BASIC = "com.chinaitop.depot.basic.controller;";
    private static final String COMMON = "com.chinaitop.depot.common.controller;";
    private static final String DATADOCKING = "com.chinaitop.depot.DataDocking.controller;";
    private static final String JOB = "com.chinaitop.depot.job.controller;";

    private static String addPackage() {
        StringBuilder countServer = new StringBuilder();
        countServer.append(BASIC).append(COMMON).append(DATADOCKING).append(JOB);
        return countServer.toString();
    }

    @Bean
    public Docket createRestApi() {
        return new Docket(DocumentationType.SWAGGER_2)
                .apiInfo(apiInfo())
                .select()
                .apis(basePackage(addPackage()))
                .paths(PathSelectors.any())
                .build();
    }
    private ApiInfo apiInfo() {
    	String url = "http://"+eureka_ip+":9001";
        return new ApiInfoBuilder()
                .title("智能粮库管理平台api文档")
                .description("基础数据")
                .termsOfServiceUrl(url.trim())
                .version("1.0")
                .build();
    }

    public static Predicate<RequestHandler> basePackage(final String basePackage) {
        return input -> declaringClass(input).transform(handlerPackage(basePackage)).or(true);
    }

    private static Function<Class<?>, Boolean> handlerPackage(final String basePackage) {
        return input -> {
            // 循环判断匹配
            for (String strPackage : basePackage.split(";")) {
                boolean isMatch = input.getPackage().getName().startsWith(strPackage);
                if (isMatch) {
                    return true;
                }
            }
            return false;
        };
    }

    private static Optional<? extends Class<?>> declaringClass(RequestHandler input) {
        return Optional.fromNullable(input.declaringClass());
    }
}
