/**
 * 
 */
package com.chinaitop.depot.basic.controller;

import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.basic.model.BasicCodeRule;
import com.chinaitop.depot.basic.model.BasicCodeRuleDetail;
import com.chinaitop.depot.basic.model.BasicCodeRuleDetailExample;
import com.chinaitop.depot.basic.model.BasicCodeRuleExample;
import com.chinaitop.depot.basic.model.BasicCodeRuleExample.Criteria;
import com.chinaitop.depot.basic.model.Enum.CodeRuleType;
import com.chinaitop.depot.basic.service.BasicCodeRuleDetailService;
import com.chinaitop.depot.basic.service.BasicCodeRuleService;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * <p>
 * Title: BasicCodeRuleController
 * </p>
 * <p>
 * Description:
 * </p>
 * 
 * @author yaoyabin
 * @date 2017年12月15日 上午10:58:45
 */
@RestController
@RequestMapping(value = "/depot/basic/codeRule")
@Api(value = "BasicCodeRuleController", description = "编码规则主表控制类")
public class BasicCodeRuleController {
	@Resource
	private BasicCodeRuleService basicCodeRuleService;
	@Resource
	private BasicCodeRuleDetailService basicCodeRuleDetailService;

	/**
	 * 列表.
	 * 
	 * @param pageNum
	 *            页码
	 * @param pageSize
	 *            每页显示条数
	 * @return
	 */
	@RequestMapping(value = "/getList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "编码规则主表数据列表查询", notes = "编码规则主表数据列表查询，支持分页")
	@ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "页数", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页显示条数", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query") })
	public PageInfo<BasicCodeRule> getList(Integer pageNum, Integer pageSize, Integer orgId) {
		List<BasicCodeRule> list = basicCodeRuleService.queryByExample(pageNum, pageSize, orgId);
		PageInfo<BasicCodeRule> pageInfo = new PageInfo<BasicCodeRule>(list);
		return pageInfo;
	}

	@RequestMapping(value = "/getDetailList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "编码规则子表数据列表查询", notes = "编码规则子表数据列表查询，支持分页")
	@ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "页数", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页显示条数", paramType = "query"),
			@ApiImplicitParam(name = "bid", value = "主表ID", paramType = "query") })
	public PageInfo<BasicCodeRuleDetail> getDetailList(Integer pageNum, Integer pageSize, Integer bid) {
		List<BasicCodeRuleDetail> list = basicCodeRuleService.getDetailList(pageNum, pageSize, bid);
		PageInfo<BasicCodeRuleDetail> pageInfo = new PageInfo<BasicCodeRuleDetail>(list);
		return pageInfo;
	}

	/**
	 * 根据id查询.
	 * 
	 * @param id
	 *            主键
	 * @return
	 */
	@RequestMapping(value = "/edit", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "根据id查询", notes = "根据id查询")
	@ApiImplicitParams({ @ApiImplicitParam(name = "id", value = "主表ID", paramType = "query") })
	public Map<String, Object> edit(Integer id) {
		Map<String, Object> returnMap = new HashMap<String, Object>();
		if (id != null) {
			// 主表数据.
			BasicCodeRule codeRule = basicCodeRuleService.findById(id);
			// 子表数据.
			List<BasicCodeRuleDetail> codeRuleDetailList = basicCodeRuleService.getDetailList(id);

			returnMap.put("codeRule", codeRule);
			returnMap.put("codeRuleDetailList", codeRuleDetailList);
		}
		return returnMap;
	}

	/**
	 * 数据更新
	 * 
	 * @param codeRuleJson
	 *            主表信息
	 * @param codeRuleDetailJson
	 *            子表信息
	 * @return
	 * @throws JsonParseException
	 * @throws JsonMappingException
	 * @throws IOException
	 */
	@SuppressWarnings("unchecked")
	@RequestMapping(value = "/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value = "数据更新", notes = "数据更新")
	@ApiImplicitParams({ @ApiImplicitParam(name = "codeRuleJson", value = "主表数据", paramType = "form"),
			@ApiImplicitParam(name = "codeRuleDetailJson", value = "子表数据", paramType = "form"),
			@ApiImplicitParam(name = "userInfo", value = "登录对象数据", paramType = "form") })
	public Map<String, Object> save(String codeRuleJson, String codeRuleDetailJson, String userInfo)
			throws JsonParseException, JsonMappingException, IOException {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		JSONObject user = null;
		Integer orgId = null;
		Integer userId = null;
		BasicCodeRuleExample example = new BasicCodeRuleExample();
		Criteria criteria = example.createCriteria();
		if (null != userInfo && !"".equals(userInfo)) {
			user = JSONObject.parseObject(userInfo);
			orgId = Integer.parseInt(user.get("orgId").toString());
			userId = Integer.parseInt(user.get("userId").toString());
		}
		try {
			// JSON字符串转对象
			ObjectMapper mapper = new ObjectMapper();
			BasicCodeRule codeRule = (BasicCodeRule) mapper.readValue(codeRuleJson, BasicCodeRule.class);
			List<BasicCodeRuleDetail> codeRuleDetailList = null;
			if (codeRuleDetailJson != null) {
				codeRuleDetailList = (List<BasicCodeRuleDetail>) mapper.readValue(codeRuleDetailJson,
						new TypeReference<List<BasicCodeRuleDetail>>() {
						});
			}
			criteria.andCodeTypeEqualTo(codeRule.getCodeType());
			criteria.andOrgIdEqualTo(orgId);
			List<BasicCodeRule> list = basicCodeRuleService.findCodeName(example);
			//如果ID存在则表明是修改数据
			if (codeRule.getId() == null) {
				//再次判断是否存在该编码规则，不存在则新增，否则弹框提示
				if (list.size() == 0 && list.isEmpty()) {
					basicCodeRuleService.add(codeRule, codeRuleDetailList, userId, orgId);
					modelMap.put("status", "success");
				} else {
					modelMap.put("status", "error");
					modelMap.put("msg", "该编码名称已存在,请勿重复添加！");
					return modelMap;
				}
			} else {
				basicCodeRuleService.update(codeRule, codeRuleDetailList);
				modelMap.put("status", "success");
			}
		} catch (Exception e) {
			e.printStackTrace();
			modelMap.put("status", "error");
			modelMap.put("msg", "保存失败！");
			return modelMap;
		}
		return modelMap;
	}

	/**
	 * 删除(同时删除流程)
	 * 
	 * @param id
	 *            主键
	 * @return
	 */
	@RequestMapping(value = "/remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value = "删除(同时删除流程)", notes = "删除(同时删除流程)")
	@ApiImplicitParams({ @ApiImplicitParam(name = "id", value = "主键", paramType = "form") })
	public Map<String, Object> remove(Integer id) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		if (id != null) {
			// 删除主表数据
			basicCodeRuleService.remove(id);
			// 删除关联子表数据
			BasicCodeRuleDetailExample example = new BasicCodeRuleDetailExample();
			BasicCodeRuleDetailExample.Criteria criteria = example.createCriteria();
			criteria.andZidEqualTo(id);
			basicCodeRuleDetailService.removeCondition(example);
		}
		modelMap.put("status", "success");
		return modelMap;
	}

	/**
	 * 根据编码类型获取编码.
	 * 
	 * @param request
	 * @param codeRuleType
	 *            编码类型.
	 * @return
	 */
	@RequestMapping(value = "/getCodeValueByType", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "根据编码类型获取编码", notes = "根据编码类型获取编码")
	@ApiImplicitParams({ @ApiImplicitParam(name = "codeRuleType", value = "编码类型", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query") })
	public Map<String, Object> getCodeValueByType(String codeRuleType, Integer orgId) {
		// 返回map.
		Map<String, Object> modelMap = new HashMap<String, Object>();
		try {
			if (orgId == null) {
				throw new RuntimeException("参数orgId为空");
			}
		} catch (Exception e) {
			modelMap.put("status", "error");
			modelMap.put("msg", "未获取到对应的组织机构，无法获取到编码！");
			return modelMap;
		}

		if (StringUtils.isNotBlank(codeRuleType)) {
			Integer codeRuleTypeEnumId = CodeRuleType.getEnumIdByType(codeRuleType);
			if (codeRuleTypeEnumId != null) {
				String codeValue = "";
				try {
					codeValue = basicCodeRuleService.getCode(codeRuleTypeEnumId, orgId);
				} catch (Exception e) {
					e.printStackTrace();
					modelMap.put("status", "error");
					modelMap.put("msg", e.getMessage());
					return modelMap;
				}
				modelMap.put("status", "success");
				modelMap.put("codeValue", codeValue);
			} else {
				modelMap.put("status", "error");
				modelMap.put("msg", "编码类型为空！");
			}
		} else {
			modelMap.put("status", "error");
			modelMap.put("msg", "编码类型为空！");
		}
		return modelMap;
	}
}
