package com.chinaitop.depot.basic.controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import com.chinaitop.depot.basic.model.BasicEnum;
import com.chinaitop.depot.basic.model.BasicEnumExample;
import com.chinaitop.depot.basic.model.BasicEnumExample.Criteria;
import com.chinaitop.depot.basic.model.BasicEnumVo;
import com.chinaitop.depot.basic.service.BasicEnumService;
import com.chinaitop.depot.common.service.ImportServiceImpl;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;


/**
 * 数据字典Controller，数据字典管理菜单中所有的功能都在这里
 * @author User
 *
 */
@RestController
@RequestMapping(value="/Enum")
@Api(value= "BasicEnumController", description = "数据字典控制类")
public class BasicEnumController {

	@Resource
	private BasicEnumService enumService;

	@Resource
    private ImportServiceImpl importService;

	@Value("${web.upload-path}")
	private String uploadPath;

	@RequestMapping(value="/getList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询字典数据", notes = "查询字典数据列表，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "parentId", value = "父级ID", paramType = "query"),
		@ApiImplicitParam(name = "enumName", value = "字典名称", paramType = "query")
	})
	public PageInfo<BasicEnum> getList(Integer pageNum, Integer pageSize, Integer parentId, String enumName) {
		BasicEnumExample enumExample = new BasicEnumExample();
		Criteria Criteria = enumExample.createCriteria();
		List<BasicEnum> list = null;
		try {
			// 拼接查询条件
			if (null != enumName && !"".equals(enumName)) {
				Criteria.andEnumnameLike("%"+enumName+"%");
			}
			Criteria.andDelflagEqualTo(1); //查询正常数据
			if (null != parentId) {
				Criteria.andParentidEqualTo(parentId); //只查询顶级菜单
			}
			if (null != pageNum && null != pageSize) {
				PageHelper.startPage(pageNum, pageSize);
			}

			list = enumService.findConditionEnum(enumExample);
		} catch (Exception e) {
			e.printStackTrace();
		}
		PageInfo<BasicEnum> pageInfo = new PageInfo<BasicEnum>(list);
		return pageInfo;
	}

	@RequestMapping(value="/findByEnum", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="按ID查询字典数据", notes = "查询一条字典数据")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "数据ID", paramType = "query")
	})
	public BasicEnum findByEnum(Integer id) {
		BasicEnum basicEnum = new BasicEnum();
		try {
			if (id != null) {
				basicEnum = enumService.findByParmeryKeyEnum(id);
			} else {
				basicEnum.setDelflag(1);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return basicEnum;
	}

	@RequestMapping(value="/edit", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="更新字典数据", notes = "新增或修改数据字典")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "enumJson", value = "字典数据对象", paramType = "form")
	})
	public Map<String, Object> edit(String enumJson) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		try {
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            BasicEnum basicEnum = (BasicEnum)mapper.readValue(enumJson, BasicEnum.class);
            if (basicEnum.getEnumid() == null) {
            	basicEnum.setDelflag(1);
            	basicEnum.setCreatedate(new Date());  //创建时间
				basicEnum = enumService.saveEnum(basicEnum);
				modelMap.put("basicEnum", basicEnum);
            } else {
            	enumService.updateEnum(basicEnum);
            }
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
		return modelMap;
	}

	@RequestMapping(value="/remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="删除字典数据", notes="删除字典数据")
	@ApiImplicitParams({
		@ApiImplicitParam(name="id", value="字典ID", paramType="form")
	})
	public Map<String, Object> remove(Integer id) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		try {
			
			// 先查询到这条数据
			BasicEnum basicEnum = enumService.findByParmeryKeyEnum(id);
			
			// 将删除标识改为0,然后在修改一次
			basicEnum.setDelflag(0);
			enumService.updateEnum(basicEnum);

			modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "删除失败！");
        }
		return modelMap;
	}

	@RequestMapping(value="/getTree", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询字典数据树", notes="查询字典数据树")
	public List<BasicEnum> getTree() {
		List<BasicEnum> list = enumService.queryByTree();
		return list;
	}

	@RequestMapping(value="/findEnumObj", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="获取枚举字典数据统一对外接口", notes="获取枚举字典数据统一对外接口")
	public Map<String, Object> findEnumObj() throws Exception {
		Map<String, Object> map = new HashMap<>();
		Map<Integer, List<BasicEnum>> parentMap = enumService.findEnumObjParentId();
		Map<Object,Object> enumMap = enumService.findEnumObjEnumId();
		map.put("parentMap", parentMap);
		map.put("enumMap", enumMap);
		return map;
	}

	@RequestMapping(value="/getAllChildren", method=RequestMethod.GET)
	@ApiOperation(value="根据id获取这个字典下所有子节点", notes="根据id获取这个字典下所有子节点")
	@ApiImplicitParams({
		@ApiImplicitParam(name="enumid", value="字典id", paramType="query")
	})
	public List<BasicEnum> getAllChildren(Integer enumid,String planManage) {
		return enumService.queryAllChildren(enumid,planManage);
	}

	/**
     * 导入excel
     * @param file
     * @param fileType 类型：如xlsx
     * @param request
     * @return
	 * @throws Exception  
     */
	@RequestMapping(value="/importFile", method=RequestMethod.POST)
    @ApiOperation(value="数据字典导入excel", notes="数据字典导入excel")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="file", value="文件数据", paramType="form"),
    	@ApiImplicitParam(name="fileType", value="文件名", paramType="form")
    })
    public String importFile(MultipartFile file, String fileType, HttpServletRequest request) throws Exception{

        String[] titleArr = {"枚举上级ID", "枚举编码", "枚举名称", "国标编码", "描述"};//第一行的title
        boolean[] emptyArr = {false  ,  false  ,  false , true  ,  true};//指定列可为空，不可为空值为false.

        String msg = "";
        List<List<String>> list = new ArrayList<List<String>>();//该list为数据返回的list
        try {
            String errormsg = importService.importFile(uploadPath, file, fileType, request, titleArr, emptyArr, list);

            if (list.size()>0)
            	msg = enumService.importData(list);

            	System.out.println(list);
            	System.out.println(errormsg);
            	System.out.println(msg);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return msg;
    }
    
	/**
     * 获取粮食性质或粮食产地字典树
     *  
     * @param request
     * @param type 类别
     * @param parentId 父编号
     * @return
     */
	@RequestMapping(value="/getTreeList", method=RequestMethod.GET)
    @ApiOperation(value="获取粮食性质或粮食产地字典树", notes="获取粮食性质或粮食产地字典树")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="type", value="字典类别", paramType="query"),
    	@ApiImplicitParam(name="parentId", value="字典父级编码", paramType="query")
    })
	public Map<String, Object> getTreeList(HttpServletRequest request, String type, Integer parentId) {
        Integer enumId = null;
        if ("grainAttribute".equals(type)) {
            // 粮食性质.
            enumId = 1032;
        } else if ("grainProducingArea".equals(type)) {
            // 粮食产地.
            enumId = 1010;
        }else if("grainDetailKind".equals(type)) {
        	// 明细品种.
            enumId = parentId;
        }
		Map<String, Object> modelMap = new HashMap<>();
		List<BasicEnum> list = this.getAllChildren(enumId,null);
		List<BasicEnumVo> voList = new ArrayList<BasicEnumVo>();
		for (BasicEnum basicEnum : list) {
			BasicEnumVo basicEnumVo = new BasicEnumVo();
			basicEnumVo.setId(basicEnum.getEnumid());
			basicEnumVo.setName(basicEnum.getEnumname());
			basicEnumVo.setParentid(basicEnum.getParentid());
			voList.add(basicEnumVo);
		}
		modelMap.put("enumList", voList);
		modelMap.put("enumId", enumId);
		return modelMap;
	}

    @RequestMapping(value="/getTreeTypeList", method=RequestMethod.GET)
    @ApiOperation(value="根据id获取这个字典下所有子节点(有固定格式数据需要)", notes="根据id获取这个字典下所有子节点(有固定格式数据需要)")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="deviceTypeId", value="字典ID", paramType="query")
    })
    public Map<String, Object> getTreeTypeList(HttpServletRequest request,Integer deviceTypeId,String planManage) {
    	Map<String, Object> modelMap = new HashMap<>();
    	List<BasicEnum> list = this.getAllChildren(deviceTypeId,planManage);
    	List<BasicEnumVo> voList = new ArrayList<BasicEnumVo>();
    	for (BasicEnum basicEnum : list) {
    		BasicEnumVo basicEnumVo = new BasicEnumVo();
    		basicEnumVo.setId(basicEnum.getEnumid());
    		basicEnumVo.setName(basicEnum.getEnumname());
    		basicEnumVo.setParentid(basicEnum.getParentid());
    		basicEnumVo.setEnumcode(basicEnum.getEnumcode());
    		basicEnumVo.setGbcode(basicEnum.getGbcode());
    		voList.add(basicEnumVo);
    	}
    	modelMap.put("enumList", voList);
    	modelMap.put("enumId", deviceTypeId);
    	return modelMap;
    }

    @RequestMapping(value="/getIdByNameAndParentId", method=RequestMethod.GET)
    @ApiOperation(value="根据名称和父ID获取ID", notes="根据名称和父ID获取ID")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="parentId", value="父ID", dataType="int", paramType="query"),
    	@ApiImplicitParam(name="enumName", value="名称", dataType="String", paramType="query"),
		@ApiImplicitParam(name="code", value="字典国标编码模糊值", dataType="String", paramType="query")
    })
    public Map<String, Object> getIdByNameAndParentId(Integer parentId,String enumName, String code) {
    	Map<String, Object> modelMap = null;
    	try {
    		modelMap = enumService.getIdByNameAndParentId(parentId, enumName, code);
    	} catch (Exception e) {
    		e.printStackTrace();
    	}
    	return modelMap;
    }
    
    @RequestMapping(value="/findConditionEnum", method=RequestMethod.GET)
    @ApiOperation(value="根据id获取一个树结构", notes="")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="parentId", value="字典父级ID", dataType="int", paramType="query"),
    	@ApiImplicitParam(name="notParentId", value="要排除的父级ID", dataType="int", paramType="query"),
    	@ApiImplicitParam(name="notEnumId", value="要排除的字典ID", dataType="int", paramType="query")
    })
    public Map<String, Object> findConditionEnum(Integer parentId, Integer notParentId, Integer notEnumId) {
    	Map<String, Object> modelMap = null;
		try {
			modelMap = enumService.findCondition(parentId, notParentId, notEnumId);
		} catch (Exception e) {
			e.printStackTrace();
		}

    	return modelMap;
    }

}
