package com.chinaitop.depot.basic.controller;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.basic.mapper.BasicKeeperMapper;
import com.chinaitop.depot.basic.model.*;
import com.chinaitop.depot.basic.model.BasicKeeperExample.Criteria;
import com.chinaitop.depot.basic.service.BasicEnumService;
import com.chinaitop.depot.basic.service.BasicKeeperEducationService;
import com.chinaitop.depot.basic.service.BasicKeeperHouseService;
import com.chinaitop.depot.basic.service.BasicKeeperService;
import com.chinaitop.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 保管员信息管理Controller，保管员信息管理菜单中所有的功能都在这里，包括给保管员分配仓房
 * 
 * @author User
 *
 */
@RestController
@RequestMapping(value = "Keeper")
@Api(value= "BasicKeeperController", description = "员工信息控制类")
public class BasicKeeperController {

	@Resource
	private BasicKeeperService keeperService;

	@Resource
	private BasicKeeperEducationService keperEduationService;

	@Resource
	private BasicEnumService enumService;
	
	@Resource
	private BasicKeeperHouseService keeperHouseService;

	@Resource
	private BasicKeeperMapper keeperMapper;

	/**
	 * 查询员工数据列表
	 * 
	 * @param pageNum 页数
	 * @param pageSize 每页显示的条数
	 * @param userId 用户ID
	 * @return
	 */
	@RequestMapping(value = "/getList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询员工数据列表", notes = "查询员工数据列表，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "name", value = "员工姓名", paramType = "query"),
		@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query"),
		@ApiImplicitParam(name = "userId", value = "用户ID", paramType = "query")
	})
	public PageInfo<BasicKeeper> getList(Integer pageNum, Integer pageSize, String keeperName, Integer orgId, Integer userId) {
		BasicKeeperExample keeperExample = new BasicKeeperExample();
		Criteria criteria = keeperExample.createCriteria();
		List<BasicKeeper> list = null;
		try {
			// 拼接查询条件
			if (!"".equals(keeperName) && keeperName != null) {
				criteria.andNameLike("%" + keeperName + "%");
			}
			if (null != orgId && !"".equals(orgId)) {
				criteria.andOrgIdEqualTo(orgId);
			}
			if (null != userId && !"".equals(userId)) {
				criteria.andUserIdEqualTo(userId);
			}
			criteria.andDelFlagEqualTo(1); // 查询正常数据
			if (null != pageNum && null != pageSize) {
				PageHelper.startPage(pageNum, pageSize);
			}
			keeperExample.setOrderByClause(" id desc");
			list = keeperService.findCondition(keeperExample);
		} catch (Exception e) {
			e.printStackTrace();
		}
		PageInfo<BasicKeeper> pageInfo = new PageInfo<BasicKeeper>(list);
		return pageInfo;
	}

	/**
	 * 通过库ID，获取保管员数据组(保管员数据对外接口)
	 * 
	 * @return
	 */
	@RequestMapping(value = "/getKeeper", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="通过单位ID，获取保管员数据组(保管员数据对外接口)", notes = "通过单位ID，获取保管员数据组(保管员数据对外接口)")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "unitId", value = "单位ID", paramType = "query")
	})
	public List<BasicKeeper> getKeeper(Integer orgId) {
		BasicKeeperExample keeperExample = new BasicKeeperExample();
		Criteria criteria = keeperExample.createCriteria();
		List<BasicKeeper> list = null;
		try {
			criteria.andOrgIdEqualTo(orgId);
			criteria.andPostTypeEqualTo(14);
			criteria.andDelFlagEqualTo(1); // 查询正常数据
			list = keeperService.findCondition(keeperExample);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return list;
	}

	/**
	 * 查询一个保管员信息(包括其它证书信息)
	 * 
	 * @param id 保管员数据ID
	 * @return
	 */
	@RequestMapping(value = "/findBasicKeeper", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询一个员工信息(包括其它证书信息)", notes = "查询一个员工信息(包括其它证书信息)")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "员工数据ID", paramType = "query")
	})
	public Map<String, Object> findBasicKeeper(Integer id) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		modelMap = keeperService.findByKeeperAll(id);
		return modelMap;
	}

	/**
	 * 查询一个保管员基础信息 (不包括其它证书信息)
	 * 
	 * @param id 保管员数据ID
	 * @return
	 */
	@RequestMapping(value = "/getBasicKeeper", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询一个员工基础信息 (不包括其它证书信息)", notes = "查询一个员工信息(不包括其它证书信息)")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "员工数据ID", paramType = "query")
	})
	public BasicKeeper getBasicKeeper(Integer id) {
		BasicKeeper keeper = keeperService.findByIdParmartKey(id);
		return keeper;
	}

	/**
	 * 更新保管员信息
	 * 
	 * @param keeper 保管员数据对象
	 * @param xwxlJson 保管员学历数据对象
	 * @param zyjsJson 保管员职业技术等级数据对象
	 * @param zyzgJson 保管员专业资格数据对象
	 * @param sgzJson 保管员上岗证数据对象
	 * @return
	 * @throws Exception 
	 */
	@RequestMapping(value = "/edit", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="更新员工信息", notes = "更新员工信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "keeper", value = "员工数据对象", paramType = "form"),
		@ApiImplicitParam(name = "xwxlJson", value = "员工学历数据对象", paramType = "form"),
		@ApiImplicitParam(name = "zyjsJson", value = "员工职业技术等级数据对象", paramType = "form"),
		@ApiImplicitParam(name = "zyzgJson", value = "员工专业资格数据对象", paramType = "form"),
		@ApiImplicitParam(name = "sgzJson", value = "员工上岗证数据对象", paramType = "form"),
		@ApiImplicitParam(name = "userInfo", value = "登录信息数据对象", paramType = "form"),
		@ApiImplicitParam(name = "jllgJson", value = "交流轮岗数据对象", paramType = "form"),
	})
	public Map<String, Object> edit(String keeper, String xwxlJson, 
			String zyjsJson, String zyzgJson, String sgzJson, String userInfo, String jllgJson) throws Exception {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		ObjectMapper mappers = new ObjectMapper();
		BasicKeeper basicKeeper = mappers.readValue(keeper, BasicKeeper.class);
		if (basicKeeper.getId() == null) {
			//校验重复添加
			BasicKeeperExample keeperExample = new BasicKeeperExample();
			BasicKeeperExample.Criteria criteria = keeperExample.createCriteria();
			criteria.andUserIdEqualTo(basicKeeper.getUserId());
			criteria.andPostTypeEqualTo(basicKeeper.getPostType());
			criteria.andDelFlagEqualTo(1);
			List<BasicKeeper> kList = keeperService.findCondition(keeperExample);
			if (null != kList && kList.size() > 0) {
				modelMap.put("status", "success");
				modelMap.put("msg", "当前员工在当前角色的信息已经存在，请不要重复添加！");
				return modelMap;
			}
		}
		keeperService.editKeeper(userInfo, keeper, xwxlJson, zyjsJson, zyzgJson, sgzJson, jllgJson);
		modelMap.put("status", "success");
		modelMap.put("msg", "保存成功！");
		return modelMap;
	}

	/**
	 * 逻辑删除保管员信息
	 * 
	 * @param id 保管员数据ID
	 * @return
	 */
	@RequestMapping(value = "/remove", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="逻辑删除员工信息", notes = "逻辑删除员工信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "员工ID", paramType = "form")
	})
	public Map<String, Object> remove(Integer id, Integer orgId) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		BasicKeeper keeper = new BasicKeeper();
		try {
			if (null != id) {
				keeper.setId(id);
				keeper.setDelFlag(0);
				keeperService.update(keeper);
				modelMap.put("status", "success");
				
				/* 清理掉他所管理的仓房 */
				BasicKeeperHouseExample example = new BasicKeeperHouseExample();
				BasicKeeperHouseExample.Criteria khCriteria = example.createCriteria();
				khCriteria.andKeeperIdEqualTo(id);
				khCriteria.andOrgIdEqualTo(orgId);
				keeperHouseService.delete(example);
			}
		} catch (Exception e) {
			e.printStackTrace();
			modelMap.put("status", "error");
			modelMap.put("msg", "删除失败！");
		}

		return modelMap;
	}

	/**
	 * 获取当前保管员所在粮库的所有仓房和当前保管员的权限
	 * 
	 * @param id 保管员ID
	 * @return
	 */
	@RequestMapping(value = "/getUnitStoreKeepList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="获取当前保管员所在粮库的所有仓房和当前保管员的权限", notes = "获取当前保管员所在粮库的所有仓房和当前保管员的权限")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query"),
		@ApiImplicitParam(name = "id", value = "员工ID", paramType = "query"),
		@ApiImplicitParam(name = "libraryType", value = "库类型，0.主粮库，1.代储点粮库", paramType = "query")
	})
	public Map<String, Object> getUnitStoreKeepList(Integer orgId, Integer id, String libraryType) {
		Map<String, Object> map = new HashMap<String, Object>();

		map = keeperService.getUnitStoreKeepList(orgId, id, libraryType);

		return map;
	}

	/**
	 * 提交保管员权限分配
	 * 
	 * @param selected 仓房权限数组(当前保管员可管理的仓房)
	 * @param bgyId 保管员ID
	 * @return
	 */
	@RequestMapping(value = "/saveKeeperHouse", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="提交保管员权限分配", notes = "提交保管员权限分配")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "selected", value = "仓房权限数组(当前保管员可管理的仓房)", paramType = "form"),
		@ApiImplicitParam(name = "userInfo", value = "登录数据对象", paramType = "form"),
		@ApiImplicitParam(name = "bgyId", value = "保管员ID", paramType = "form")
	})
	public Map<String, Object> saveKeeperHouse(String selected, String userInfo, Integer bgyId) {
		Map<String, Object> map = new HashMap<String, Object>();

		try {
			keeperService.saveKeeperHouse(selected, bgyId, userInfo);
			map.put("status", "success");
		} catch (Exception e) {
			e.printStackTrace();
			map.put("status", "error");
			map.put("msg", "删除失败！");
		}
		return map;
	}

	/**
	 * 删除一条保管员证件信息
	 * 
	 * @param id 证件数据ID
	 * @return
	 */
	@RequestMapping(value = "/removeEducation", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="删除一条证件信息", notes = "提交保管员权限分配")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "证件数据ID", paramType = "form")
	})
	public Map<String, Object> removeEducation(Integer id) {
		Map<String, Object> map = new HashMap<String, Object>();

		try {
			keperEduationService.delete(id);
			map.put("status", "success");
		} catch (Exception e) {
			e.printStackTrace();
			map.put("status", "error");
			map.put("msg", "删除失败！");
		}
		return map;
	}

	@RequestMapping(value = "getKepperByHouseId", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="根据仓房id获取保管员", notes = "根据仓房id获取保管员")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query")
	})
	public List<BasicKeeper> getKepperByHouseId(Integer houseId) {
		return keeperService.getKepperByHouseId(houseId);
	}

	@RequestMapping(value = "/receivedUserByOrgId", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询当前保管员所在库中的所有保管员（排除掉当前登录的保管员用户）", notes = "查询当前保管员所在库中的所有保管员（排除掉当前登录的保管员用户）")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "userInfo", value = "登录数据对象JSON", paramType = "query"),
		@ApiImplicitParam(name = "roleId", value = "登录数据对象JSON", paramType = "query")
	})
	public List<BasicKeeper> receivedUserByOrgId(String userInfo,Integer roleId) {
		JSONObject user = null;
		Integer orgId = null;
        Integer userId = null;
        if (null != userInfo && !"".equals(userInfo)) {
        	user = JSONObject.parseObject(userInfo);
        	orgId = Integer.parseInt(user.get("orgId") == null?"":user.get("orgId").toString());
        	userId = Integer.parseInt(user.get("userId") == null?"":user.get("userId").toString());
        }
		BasicKeeperExample keeperExample = new BasicKeeperExample();
		Criteria criteria = keeperExample.createCriteria();
		List<BasicKeeper> list = null;
		//BasicEnum basicEnum = null;
		//String keeperId ="";
		try {
			    //5417保管员角色编号Id  enumCode对应的就是保管员的id
			 	//basicEnum = enumService.findByParmeryKeyEnum(5417);
			 	//keeperId=basicEnum.getEnumcode();//保管员角色对应的id
			// 拼接查询条件单位
			if (null != orgId && !"".equals(orgId)) {
				criteria.andGrainIdEqualTo(orgId);
			}
			//排除掉当前登录的保管员用户，只返回该库除登录人的保管员用户
			if(userId !=null && !"".equals(userId)){
				criteria.andUserIdNotEqualTo(userId);
			}
			criteria.andDelFlagEqualTo(1); // 查询正常数据
			criteria.andPostTypeEqualTo(roleId);//查询类型为保管员的记录
			list = keeperService.findCondition(keeperExample);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return list;
	}

	/**
	 * 查询当前登录用户所对应的保管员信息
	 * 
	 * @param userId 用户ID
	 * @return
	 */
	@RequestMapping(value = "/getKeeperByLoginUser", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询当前登录用户所对应的保管员信息", notes = "查询当前登录用户所对应的保管员信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "userId", value = "用户ID", paramType = "query"),
			@ApiImplicitParam(name = "roleId", value = "保管员ID", paramType = "query")
	})
	public  BasicKeeper getKeeperByLoginUser(Integer userId,Integer roleId) {
		BasicKeeper  keeper = new BasicKeeper();
		/*BasicEnum basicEnum = null;
		String keeperId ="";*/
		try {
			//5417保管员角色编号Id  enumCode对应的就是保管员的id
			//basicEnum = enumService.findByParmeryKeyEnum(5417);
			//keeperId=basicEnum.getEnumcode();//保管员角色对应的id
			//排除掉当前登录的保管员用户，只返回该库除登录人的保管员用户

			BasicKeeperExample keeperExample = new BasicKeeperExample();
			Criteria criteria = keeperExample.createCriteria();
			if(userId !=null && !"".equals(userId)){
				criteria.andUserIdEqualTo(userId);
			}
			if(roleId !=null && !"".equals(roleId)){
				//查询角色是保管员的对应的信息
				criteria.andPostTypeEqualTo(roleId);
			}
			keeperExample.setOrderByClause("id desc");
			List<BasicKeeper> keeperList = keeperService.findCondition(keeperExample);
			if (null != keeperList && keeperList.size() > 0) {
				keeper = keeperList.get(0);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return keeper;
	}

	/**
	 * 查询当前登录的保管员所管理的仓房
	 * 
	 * @return
	 */
	@RequestMapping(value = "/getKeeperByBarn", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询当前登录的保管员所管理的仓房", notes = "查询当前登录的保管员所管理的仓房")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "userInfo", value = "登录数据对象JSON", paramType = "query")
	})
	public List<BasicKeeper> getKeeperByBarn(String userInfo) {
		JSONObject user = null;
        Integer userId = null;
        if (null != userInfo && !"".equals(userInfo)) {
        	user = JSONObject.parseObject(userInfo);
        	userId = Integer.parseInt(user.get("userId") == null?"":user.get("userId").toString());
        }
		List<BasicKeeper> keeperList = null;
		try {
			Map<String,Object> map = new HashMap<>();
			map.put("userId",userId);
			keeperList = keeperService.findBarn(map);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return keeperList;
	}

	/**
	 * 当前仓所对应的保管员
	 */
	@RequestMapping(value="/getKeeperNamesByHouseId", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询当前仓所对应的保管员", notes = "查询当前仓所对应的保管员")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "form")
	})
	public BasicKeeper getKeeperNamesByHouseId(Integer houseId){
		BasicKeeperHouseExample keeperHouseExample = new BasicKeeperHouseExample();
		BasicKeeperHouseExample.Criteria keeperHouseCriteria = keeperHouseExample.createCriteria();
		keeperHouseCriteria.andHouseIdEqualTo(houseId);
		BasicKeeper keeper = new BasicKeeper();
		StringBuffer sb = new StringBuffer();
		List<BasicKeeperHouse> keeperHouseList = keeperHouseService.findCondition(keeperHouseExample);
		if(keeperHouseList.size()>0 && keeperHouseList != null){
			for(BasicKeeperHouse akh : keeperHouseList){
				keeper = keeperMapper.selectByPrimaryKey(Integer.valueOf(akh.getKeeperId()));
				if(keeper != null){
					sb.append(keeper.getName()+",");
				}
			}
		}
		if(sb.length() != 0){
			 keeper.setKeeperNames(sb.substring(0,sb.length()-1));
		}
		return keeper;
    }

	/**
	 * 查询保管员数据列表(只查保管员)
	 *
	 * @param pageNum 页数
	 * @param pageSize 每页显示的条数
	 * @param storehouseId 仓房ID
	 * @return
	 */
	@RequestMapping(value = "/getKeeperList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询保管员数据列表", notes = "查询保管员数据列表")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页数", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页显示的条数", paramType = "query"),
		@ApiImplicitParam(name = "keeperName", value = "保管员姓名", paramType = "query"),
		@ApiImplicitParam(name = "storehouseId", value = "仓房ID", paramType = "query"),
		@ApiImplicitParam(name = "roleId", value = "保管员id", paramType = "query")
	})
	public PageInfo<BasicKeeper> getKeeperList(Integer pageNum, 
			Integer pageSize, String keeperName, Integer storehouseId, Integer orgId ,Integer roleId) {
		BasicKeeperExample keeperExample = new BasicKeeperExample();
		Criteria criteria = keeperExample.createCriteria();
		List<BasicKeeper> list = null;
		try {
			if (storehouseId == null) {
				// 拼接查询条件
				if (!"".equals(keeperName) && keeperName != null) {
					criteria.andNameLike("%" + keeperName + "%");
				}

				criteria.andPostTypeEqualTo(roleId);//查询保管员 该类型是14
				criteria.andDelFlagEqualTo(1); // 查询正常数据
				if(ParameterUtil.isnotnull(orgId)){
					criteria.andOrgIdEqualTo(orgId);//单位
				}
				if (null != pageNum && null != pageSize) {
					PageHelper.startPage(pageNum, pageSize);
				}
				list = keeperService.findCondition(keeperExample);
			}else{
					if (null != pageNum && null != pageSize) {
						PageHelper.startPage(pageNum, pageSize);
					}
					list = keeperService.getKeeperListByNameAndHouseId(keeperName, storehouseId);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		PageInfo<BasicKeeper> pageInfo = new PageInfo<BasicKeeper>(list);
		return pageInfo;
	}
	@RequestMapping(value="/updateKeeperHouse", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="更新保管员管理的仓房", notes = "更新保管员管理的仓房")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "form"),
			@ApiImplicitParam(name = "receiveId", value = "接收人ID", paramType = "form"),
			@ApiImplicitParam(name = "transferId", value = "移交人ID", paramType = "form"),
			@ApiImplicitParam(name = "roleId", value = "保管员ID", paramType = "form"),
	})
	public Map<String, Object> updateKeeperHouse(Integer houseId, Integer receiveId,Integer transferId,Integer roleId){
		Map<String,Object> modelMap = new HashMap<String,Object>();
		/**保管员移交步骤
		 * 更新移交人和接收人在仓房和保管员表中中的记录basic_keeper_house表
		 */
		try {
			//更新移交人和接收人在仓房和保管员表中的记录basic_keeper_house表
			//得到对应的保管员
			BasicKeeper keeper=keeperService.findKeeperHouseByUserId(transferId,roleId);
			//根据移交人的id和仓号删除在basic_keeper_house表中的记录
			keeperHouseService.deleteByKeeperIdAndHouseId(keeper.getId(),houseId);

			//获取接收人的id
			Integer rId=keeperService.findKeeperHouseByUserId(receiveId,roleId).getId();
			BasicKeeperHouse keeperHouse = new BasicKeeperHouse();
			keeperHouse.setHouseId(houseId);//移交的仓房
			keeperHouse.setKeeperId(rId);//接收人的id
			keeperHouse.setOrgId(keeper.getGrainId());//登录的人所在库点
			keeperHouse.setCreateId(keeper.getId());//登录人（移交人）
			keeperHouse.setCreateTime(new Date());

			//如果移交人和接收人管理的有相同的仓号，
			// 那么移交后会出现house_keeper_houer表的keeperId和houseId相同，就会出现报错，这里特殊处理
			BasicKeeperHouse basicKeeperHouse=keeperHouseService.getHouseKeeperBykeeperIdAndHouseId(rId,houseId);
			if(basicKeeperHouse == null){
				//进行保存
				keeperHouseService.save(keeperHouse);
			}
			modelMap.put("msg","success");
		}catch (Exception ex){
			modelMap.put("msg", "error");
			ex.printStackTrace();
		}
		return modelMap;
	}
}