package com.chinaitop.depot.basic.controller;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.basic.model.BasicProcessMain;
import com.chinaitop.depot.basic.model.BasicProcessMainExample;
import com.chinaitop.depot.basic.model.BasicProcessMainExample.Criteria;
import com.chinaitop.depot.basic.model.BasicProcessSub;
import com.chinaitop.depot.basic.model.BasicProcessSubExample;
import com.chinaitop.depot.basic.service.BasicProcessMainService;
import com.chinaitop.depot.basic.service.BasicProcessSubService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/BasicProcessMainController")
@Api(value= "BasicProcessMainController", description = "工作流程配置控制类")
public class BasicProcessMainController {

	@Resource
	private BasicProcessMainService mainService;
	@Resource
	private BasicProcessSubService SubService;

	@RequestMapping(value="/getList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询工作流程数据", notes = "查询工作流程数据列表，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "parentId", value = "父级ID", paramType = "query"),
		@ApiImplicitParam(name = "enumName", value = "字典名称", paramType = "query")
	})
	public PageInfo<BasicProcessMain> getList(Integer pageNum, Integer pageSize, Integer orgId) {
		BasicProcessMainExample processMainExample = new BasicProcessMainExample();
		//Criteria Criteria = processMainExample.createCriteria();
		List<BasicProcessMain> list = null;
		try {
			// 拼接查询条件
			if (null != pageNum && null != pageSize) {
				PageHelper.startPage(pageNum, pageSize);
			}
			processMainExample.setOrderByClause("create_time asc");

			list = mainService.selectByExample(processMainExample);
		} catch (Exception e) {
			e.printStackTrace();
		}
		PageInfo<BasicProcessMain> pageInfo = new PageInfo<BasicProcessMain>(list);
		return pageInfo;
	}

	@RequestMapping(value="/edit", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询一条工作流的配置信息", notes = "查询一条工作流的配置信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "数据ID", paramType = "query")
	})
	public Map<String, Object> edit(Integer id) {
		/* 最后返回对象 */
		Map<String, Object> map = new HashMap<String, Object>();
		if (id == null) {
			map.put("mainProcess", new BasicProcessMain());
			map.put("subProcess", new ArrayList<BasicProcessSub>());
			return map;
		}

		/* 查询主表数据 */
		BasicProcessMainExample processMainExample = new BasicProcessMainExample();
		Criteria mainaCriteria = processMainExample.createCriteria();
		mainaCriteria.andIdEqualTo(id);
		BasicProcessMain mainProcess = mainService.selectByPrimaryKey(id);
		map.put("mainProcess", mainProcess);

		/* 查询主表数据 */
		BasicProcessSubExample processSubExample = new BasicProcessSubExample();
		BasicProcessSubExample.Criteria subCriteria = processSubExample.createCriteria();
		subCriteria.andMainIdEqualTo(id);
		List<BasicProcessSub> subProcess_list = SubService.selectByExample(processSubExample);
		map.put("subProcess", subProcess_list);

		return map;
	}
}
