package com.chinaitop.depot.basic.controller;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.ObjectUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.basic.model.BasicTank;
import com.chinaitop.depot.basic.model.BasicTankExample;
import com.chinaitop.depot.basic.model.BasicTankExample.Criteria;
import com.chinaitop.depot.basic.service.BasicTankService;
import com.chinaitop.depot.common.service.ImportServiceImpl;
import com.chinaitop.utils.BasicTankDataSynchronization;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;


/**
 * 油罐管理Controller，仓房管理菜单中所有的功能都在这里
 *
 * @author User
 *
 */
@RestController
@RequestMapping(value = "/Tank")
@Api(value= "BasicTankController", description = "油罐管理控制类")
public class BasicTankController {

	final static Logger logger = LoggerFactory.getLogger(BasicTank.class);

    @Resource
    private BasicTankService basicTankService;

    @Value("${web.upload-path}")
    private String uploadPath;

    @Resource
    private ImportServiceImpl importService;


    /**
     * 查找油罐信息
     * @param pageNum 页数
     * @param pageSize 每页显示的条数
     * @return
     */
    @RequestMapping(value = "/getList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询油罐信息数据列表", notes = "查询仓房信息数据列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "storagetankName", value = "油罐名称", paramType = "query"),
            @ApiImplicitParam(name = "libraryType", value = "判断是代储点还是主库", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
    })
    public PageInfo<BasicTank> getList(Integer pageNum, Integer pageSize,String storagetankName,String libraryType,Integer orgId) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<BasicTank> list = null;
        try {
            if (null != storagetankName && !"".equals(storagetankName)) {
                modelMap.put("storehouseName", "%"+storagetankName+"%");
            }
            if(orgId != null){
                modelMap.put("orgId",orgId);
            }
            //0是主库，1是代储点
            if (null != libraryType && !"".equals(libraryType)) {
                modelMap.put("libraryType",libraryType);
            }

            list = basicTankService.findBasicTankNew(modelMap);
            
            //获取当前仓房的保管员
			if (null != list && list.size() > 0) {
				String keeperNames = "";
				for (BasicTank tank : list) {
					keeperNames = basicTankService.getStorehouseKeeper(tank.getId(), tank.getOrgId(), true);
					tank.setKeepNames(keeperNames);
				}
			}

        } catch (Exception e) {
            e.printStackTrace();
        }
        PageInfo<BasicTank> pageInfo = new PageInfo<>(list);

        return pageInfo;
    }

    @RequestMapping(value = "/edit", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="更新油罐信息", notes = "更新油罐信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tankJson", value = "JSON数据对象", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "form")
    })
    public Map<String, Object> edit(HttpServletRequest request, String tankJson, Integer orgId) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
            modelMap = basicTankService.updateOrSave(request, tankJson, orgId);
        } catch (Exception e) {
            //e.printStackTrace();
            logger.error(e.getMessage(), e);
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
        return modelMap;
    }

    /**
     * 按油罐编码进行查询，去重
     * @param storageTankCode 油罐编码
     */
    @RequestMapping(value="/findStorageTankCode", method=RequestMethod.GET)
    @ApiOperation(value="防止油罐编码重复添加", notes = "storageTankCode参数")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "storageTankCode", value = "添加没有值,修改可以有壹条", paramType = "query"),
            @ApiImplicitParam(name = "id", value = "id", paramType = "form")
    })
    public boolean findStorageTankCode(String storageTankCode, String id) {

        BasicTankExample basicTankExample = new BasicTankExample();
        BasicTankExample.Criteria criteria = basicTankExample.createCriteria();

        if (null != storageTankCode) {
            criteria.andStoragetankCodeEqualTo(storageTankCode);
        }
        Boolean b = basicTankService.findStorageTankCodeList(basicTankExample, id);

        return b;
    }

    /**
     * 根据ID查找油罐信息
     *
     * @param id 数据ID
     * @return
     */
    @RequestMapping(value = "/findByTank", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据ID查找油罐信息", notes = "根据ID查找油罐信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "query")
    })
    public BasicTank findByTank(String id) {
        BasicTank basicTank = null;
        try {
            if (id != null && !"".equals(id)) {
                basicTank = basicTankService.findByPrimary(id);
            } else {
                basicTank = new BasicTank();
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
        return basicTank;
    }

    /**
     * 按油罐ID启用弃用
     *
     * @param id 数据ID
     * @return
     */
    @RequestMapping(value = "/remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="按油罐ID启用弃用", notes = "按油罐ID启用弃用")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form"),
            @ApiImplicitParam(name = "delFlag", value = "启用弃用", paramType = "form")
    })
    public Map<String, Object> remove(String id, Integer delFlag) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
            basicTankService.updateBasicTank(id, delFlag);
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "操作失败！");
        }
        return modelMap;
    }

    /**
     * 导入excel
     * @param file 文件
     * @param fileType 类型：如xlsx
     * @param request
     * @return
     */
    @RequestMapping(value="/importFile", method=RequestMethod.POST)
    @ApiOperation(value="导入仓房货位excel", notes = "导入仓房货位excel")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "file", value = "文件数据", paramType = "form"),
            @ApiImplicitParam(name = "fileType", value = "文件名称", paramType = "form"),
            @ApiImplicitParam(name = "userInfo", value = "JSON登录对象", paramType = "form"),
            @ApiImplicitParam(name = "orgCode", value = "组织编码", paramType = "form")
    })
    public String importFile(MultipartFile file, String fileType, String userInfo, HttpServletRequest request,String orgCode){

        JSONObject user = null;
        if (null != userInfo && !"".equals(userInfo)) {
            user = JSONObject.parseObject(userInfo);
        }

        String[] titleArr = {"油罐编码", "油罐名称", "油罐容量(吨)", "直径(米)", "高度(米)","建造日期"};//第一行的title
        boolean[] emptyArr = {false, false, false, false, false, false};//指定列可为空，不可为空值为false.

        List<List<String>> list = new ArrayList<List<String>>();//该list为数据返回的list
        String errormsg = null;
        try {
            errormsg = importService.importFile(uploadPath, file, fileType, request, titleArr, emptyArr, list);

            if (errormsg != null && !"".equals(errormsg)) {
                return errormsg;
            }

            if (list.size()>0) {
                errormsg = basicTankService.importData(list, user,orgCode);

                System.out.println(list);
                System.out.println(errormsg);
                //errormsg = "导入成功！";
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return errormsg;
    }

    //库点信息同步
  	@SuppressWarnings("all")
  	@RequestMapping("/warehouseSynchronization")
  	@ApiOperation(value="油罐信息同步", notes = "油罐信息同步")
  	public void orgInfoSynchronization() {
  		SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSSZ");
  		List list = BasicTankDataSynchronization.queryTank();
  		BasicTankExample example = new BasicTankExample();
  		List<BasicTank> tankList = basicTankService.findBasicTank(example);
  		for(BasicTank tank : tankList) {
  			int num = 0;
  			for(int i=0;i<list.size();i++) {
  				Map<String,Object> map = (Map<String,Object>)list.get(i);
  				String ygbh = ObjectUtils.toString(map.get("ygbh"),"");//库点编码
  				String refreshTime = ObjectUtils.toString(map.get("refreshTime"),"");
  				if(ygbh.equals(ObjectUtils.toString(tank.getStoragetankCode(),""))) {
  					if(!refreshTime.equals(format.format(tank.getUpdatetime()))) {
  						BasicTankDataSynchronization.tankSynchronizationUpdate(map, tank);
  					}
  					break;
  				}else if(num == (list.size()-1)){
  					BasicTankDataSynchronization.tankSynchronizationInsert(tank);
  				}else {
  					num = num+1;
  				}
  			}
  		}
  	}
  	
  	
  	@RequestMapping(value="/getTankIdBySptDataID", method=RequestMethod.GET)
	@ApiOperation(value="查询油罐id根据货位编码", notes = "查询油罐id根据货位编码")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "sptDataId", value = "和市平台对接的货位编码", paramType = "query")
	})
	public String getTankIdBySptDataID(String sptDataId) {
  		String a = "0";	
		BasicTankExample example = new BasicTankExample();
		Criteria criteria = example.createCriteria();
		criteria.andSptDataidEqualTo(sptDataId);
  		List<BasicTank> tankList = basicTankService.findBasicTank(example);
  		
		if(tankList.size()>0){
			a = tankList.get(0).getId();
		}
		return a;
	}

}