package com.chinaitop.depot.basic.controller;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.basic.model.BasicTank;
import com.chinaitop.depot.basic.model.BasicTankExample;
import com.chinaitop.depot.basic.model.PurchaseContractAccount;
import com.chinaitop.depot.basic.model.PurchaseContractAccountExample;
import com.chinaitop.depot.basic.service.BasicTankService;
import com.chinaitop.depot.basic.service.PurchaseContractAccountService;
import com.chinaitop.depot.common.service.ImportServiceImpl;
import com.chinaitop.utils.BasicTankDataSynchronization;
import com.chinaitop.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang.ObjectUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.text.SimpleDateFormat;
import java.util.*;


@RestController
@RequestMapping(value = "/purchaseContractAccount")
@Api(value= "PurchaseContractAccountController", description = "购销合同台账")
public class PurchaseContractAccountController {

	final static Logger logger = LoggerFactory.getLogger(PurchaseContractAccount.class);

    @Resource
    private PurchaseContractAccountService purchaseContractAccountService;

    /**
     * 查询购销合同台账
     * @param pageNum 页数
     * @param pageSize 每页显示的条数
     * @return
     */
    @RequestMapping(value = "/pageList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询购销合同台账", notes = "查询购销合同台账列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
    })
    public PageInfo<PurchaseContractAccount> pageList(Integer pageNum, Integer pageSize,Integer orgId) {
        PurchaseContractAccountExample example = new PurchaseContractAccountExample();
        PurchaseContractAccountExample.Criteria criteria = example.createCriteria();
        if(orgId!=null){
            criteria.andOrgIdEqualTo(orgId);
        }
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<PurchaseContractAccount> list = purchaseContractAccountService.getList(example);
        PageInfo<PurchaseContractAccount> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }

    @RequestMapping(value = "/add", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="新增/编辑购销合同台账", notes = "新增/编辑购销合同台账")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "purchaseContractAccountJson", value = "JSON数据对象", paramType = "form")
    })
    public Map<String, Object> add(HttpServletRequest request, String purchaseContractAccountJson) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        try {
            PurchaseContractAccount purchaseContractAccount = mapper.readValue(purchaseContractAccountJson, PurchaseContractAccount.class);
            if(purchaseContractAccount.getId()!=null){
                purchaseContractAccountService.update(purchaseContractAccount);
            }else{
                purchaseContractAccount.setCreateTime(new Date());
                purchaseContractAccountService.add(purchaseContractAccount);
            }
            modelMap.put("status", "success");
        } catch (Exception e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    @RequestMapping(value = "/remove", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id删除购销合同台账", notes = "根据id删除购销合同台账")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键id", paramType = "query")
    })
    public Map<String, Object> remove(Integer id) {
        Map<String, Object> modelMap = new HashMap<>();
        try {
            if (id != null) {
                purchaseContractAccountService.remove(id);
                modelMap.put("status", "success");
            } else {
                modelMap.put("status", "error");
            }
        } catch (Exception e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }
}