package com.chinaitop.depot.basic.service;

import com.chinaitop.depot.basic.model.BasicKeeper;
import com.chinaitop.depot.basic.model.BasicKeeperExample;

import java.util.List;
import java.util.Map;

public interface BasicKeeperService {

	/**
	 * 添加
	 * @param keeper
	 */
	public void add(BasicKeeper keeper);
	
	/**
	 * 删除
	 * @param id
	 */
	public void delete(Integer id);
	
	/**
	 * 修改
	 * @param keeper
	 */
	public void update(BasicKeeper keeper);
	
	/**
	 * 查询一条数据
	 * @param id
	 * @return
	 */
	public BasicKeeper findByIdParmartKey(Integer id);

	/**
	 * 按照ID查询一个保管员和他的所有学历等信息
	 * @param id
	 * @return
	 */
	public Map<String, Object> findByKeeperAll(Integer id);

	/**
	 * 查询一组数据
	 * @param example
	 * @return
	 */
	public List<BasicKeeper> findCondition(BasicKeeperExample example);

	/**
	 * 获取当前保管员所在粮库的所有仓房和当前保管员的权限
	 * @param unitId 当前保管员所在单位
	 * @param id 当前保管员的ID
	 * @param libraryType 库类型，0.主粮库，1.代储点粮库
	 * @return
	 */
	public Map<String, Object> getUnitStoreKeepList(Integer unitId, Integer id, String libraryType);
	/**
	 * 保管员仓房权限提交
	 * @param selected 被选中的数据
	 * @param userInfo 登录数据对象
	 * @param bgyId 保管员ID
	 * @return
	 */
	public void saveKeeperHouse(String selected, Integer bgyId, String userInfo);

	/**
	 * 更新保管员基本信息和各种证书信息
	 * @param keeperJson
	 * @param xwxlJson
	 * @param zyjsJson
	 * @param zyzgJson
	 * @param sgzJson
	 * @param jllgJson
	 * @throws Exception 
	 */
	public void editKeeper(String userInfo, String keeper, String xwxlJson, String zyjsJson, String zyzgJson, String sgzJson, String jllgJson) throws Exception;

	/**
	 * 根据移交人的id更新保管员的仓号
	 * @param houseId
	 * @param transferId
	 */
	public void removeHouseKeeperByTransferId(Integer houseId,Integer transferId);

	/**
	 * 根据接收人的id更新保管员的仓号
	 * @param houseId
	 * @param receiveId
	 */
	public void addHouseKeeperbyReceiveId(Integer houseId,Integer receiveId);

	/**
	 * 根据用户的id得到除当前登录人之外的其他保管员的id
	 * 
	 * @param userId 用户ID
	 * @return
	 */
	public BasicKeeper findKeeperHouseByUserId(Integer userId,Integer roleId);

	/**
	 * 根据仓房id获取到仓管员信息
	 * 
	 * @param houseId
	 * @return
	 */
	List<BasicKeeper> getKepperByHouseId(Integer houseId);

	/**
	 * 根据用户获取保管员管理的全部仓房
	 * 
	 * @param map
	 * @return
	 */
	List<BasicKeeper> findBarn(Map<String,Object> map);

	/**
	 * 根据名字和仓房id
	 *@param storehouseId
	 * @param name
	 * @return
	 */
	List<BasicKeeper> getKeeperListByNameAndHouseId(String name,Integer storehouseId);

	/**
	 * 获取一批员工的员工名称
	 * 
	 * @param keep_list
	 * @return
	 */
	public String getKeeperNames(List<Integer> keep_list);
}
