package com.chinaitop.depot.basic.service;

import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.basic.model.BasicStorehouse;
import com.chinaitop.depot.basic.model.BasicStorehouseExample;

public interface BasicStorehouseService {

	/**
	 * 新增仓房信息
	 * 
	 * @param basicStorehouse
	 * @throws Exception
	 */
	public void addBasicStorehouse(BasicStorehouse basicStorehouse) throws Exception;

	/**
	 * 删除仓房信息
	 * 
	 * @throws Exception
	 */
	public void removeBasicStorehouse(Integer id) throws Exception;

	/**
	 * 修改仓房信息
	 * 
	 * @throws Exception
	 */
	public void updateBasicStorehouse(BasicStorehouse basicStorehouse) throws Exception;

	/**
	 * 按照主键ID查询一条数据
	 * 
	 * @param id
	 * @return
	 * @throws Exception
	 */
	public BasicStorehouse findByPrimary(Integer id) throws Exception;

	/**
	 * 按条件查询一组数据
	 * 
	 * @param basicStorehouseExample
	 * @return
	 * @throws Exception
	 */
	public List<BasicStorehouse> findBasicStorehouse(BasicStorehouseExample basicStorehouseExample) throws Exception;

	/**
	 * 按条件查询一组数据
	 *
	 * @param map
	 * @return
	 * @throws Exception
	 */
	public List<BasicStorehouse> findBasicStorehouseNew(Map<String, Object> map) throws Exception;

	/**
	 * 查询符合条件的数据总数
	 * 
	 * @param basicStorehouseExample
	 * @return
	 * @throws Exception
	 */
	public int count(BasicStorehouseExample basicStorehouseExample) throws Exception;

	/**
	 * 按照单位ID和粮库类型获取仓房数据（统一对外接口）
	 * 
	 * @param depotId 单位ID
	 * @param libraryType 库类型，0.主粮库，1.代储点粮库
	 * @return
	 */
	public Map<String, Object> getStorehouseData(Integer depotId, String libraryType) throws Exception;

	/**
	 * 导入
	 * 
	 * @param list
	 * @param depotInfo 
	 * @return
	 */
	public String importData(List<List<String>> list, JSONObject userInfo);

	/**
	 * 根据仓房ID获取当前仓房的保管员名称
	 * 
	 * @param id 仓房ID
	 * @param orgId 单位ID
	 * @param flag 是否需要格式化省略
	 * @return
	 */
	public String getStorehouseKeeper(Integer id, Integer orgId, boolean flag);

	/**
	 * 查询三温检查列表最新数据所对应的仓房
	 * 
	 * @param orgId 粮库ID
	 * @return
	 */
	public Map<String, Object> getThreeTempCheckList(Integer orgId);

	public BasicStorehouse getStoreDataByHouseId(int houseId);

	/**
	 * 更新仓房信息
	 * 
	 * @param storehouseJson
	 * @param warehouseJson
	 * @param userInfo 
	 * @return
	 * @throws Exception
	 */
	public Map<String, Object> saveOrUpdate(HttpServletRequest request, String storehouseJson, String warehouseJson, String userInfo) throws Exception;

	//更新单位表中仓房数和货位数
	public void editOrgChNum(Integer orgId) throws Exception;

	/**
	 * 接收市局企业端传过来的仓房数据
	 * @param datas
	 * @return
	 * @throws Exception
	 */
	public Map<String, String> saveOrUpdateSptStorehouseData(String datas) throws Exception;
}
