package com.chinaitop.depot.basic.service;

import java.util.List;
import java.util.Map;

import com.chinaitop.depot.Object.HwObj;
import com.chinaitop.depot.basic.model.BasicStorehouse;
import com.chinaitop.depot.basic.model.BasicWarehouse;
import com.chinaitop.depot.basic.model.BasicWarehouseExample;
import com.chinaitop.depot.basic.model.BasicWarehouseVO;

public interface BasicWarehouseService {

	/**
	 * 新增
	 * @param basicWarehouse
	 */
	void add(BasicWarehouse basicWarehouse);

	/**
	 * @param warehouseJson 货位数据
	 * @param userInfo 当前登录的用户数据
	 * @param orgInfoJson 当前的粮库数据
	 * @throws Exception
	 */
	void edit(String warehouseJson, String userInfo, String orgInfoJson) throws Exception;
	
	/**
	 * 修改
	 * @param basicWarehouse
	 */
	void update(BasicWarehouse basicWarehouse);
	
	/**
	 * 删除
	 * @param id
	 */
	void delete(Integer id);
	
	/**
	 * 按ID查询一条数据
	 * @param id
	 * @return
	 */
	BasicWarehouse findByParmaryKey(Integer id);
	
	/**
	 * 按条件查询一组数据
	 * @param example
	 * @return
	 */
	List<BasicWarehouse> findCondition(BasicWarehouseExample example);

	/**
	 * 查询空的货位和油罐
	 * @param warehouseId 
	 * @param houseId 
	 * @param example
	 * @return
	 */
	List<Map<String, Object>> selectWareAndTank(Integer orgId, Integer houseId, Integer warehouseId) throws Exception;
	
	/**
	 * 货位信息对外接口
	 * @param unitId 单位ID
	 * @param storehouseId 仓房ID
	 * @param libraryType 库类型(0主粮库,1代储库)
	 * @return
	 */
	Map<String, Object> getWarehouse(Integer unitId, Integer storehouseId, String libraryType);

	/**
	 * 按仓房ID删除货位数据
	 * 
	 * @param storehouseId 仓房ID
	 */
	void deletEexample(Integer storehouseId);

	BasicWarehouseVO getWareDataByHwbm(String hwbm);

	/**
	 * 修改货位出入库状态
	 * 
	 * @param param
	 */
	void updateWareStatus(Map<String, Object> param);

	/**
	 * 更新货位数据
	 * 
	 * @param basicStorehouse
	 * @param warehouseJson
	 */
	void saveOrUpdate(BasicStorehouse basicStorehouse, String warehouseJson) throws Exception;

	/**
	 * 出入库状态修改规则
	 * @param hwObjs
	 */
	void editRuleMethod(List<HwObj> hwObjs) throws Exception;

	/**
	 * 根据市平台货位主键ID查询一条货位数据
	 * @param sptDataId
	 * @return
	 */
	Map<String, Object> getWareOrTank(String sptDataId) throws Exception;
}
