package com.chinaitop.depot.basic.service.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;

import com.chinaitop.depot.basic.mapper.BasicEnumMapper;
import com.chinaitop.depot.basic.model.BasicEnum;
import com.chinaitop.depot.basic.model.BasicEnumExample;
import com.chinaitop.depot.basic.model.BasicEnumVo;
import com.chinaitop.depot.basic.model.BasicEnumExample.Criteria;
import com.chinaitop.depot.basic.service.BasicEnumService;

@Service
public class BasicEnumServiceImpl implements BasicEnumService {

	@Resource
	private BasicEnumMapper enumMapper;
	
	@Override
	public BasicEnum saveEnum(BasicEnum basicEnum) throws Exception {

		//保存我方枚举数据
		enumMapper.insertSelective(basicEnum);
		return basicEnum;
	}

	@Override
	public void removeEnum(Integer id) throws Exception {
		enumMapper.deleteByPrimaryKey(id);
	}

	@Override
	public void updateEnum(BasicEnum basicEnum) throws Exception {
		enumMapper.updateByPrimaryKey(basicEnum);
	}

	@Override
	public BasicEnum findByParmeryKeyEnum(Integer id) throws Exception {
		return enumMapper.selectByPrimaryKey(id);
	}

	@Override
	public List<BasicEnum> findConditionEnum(BasicEnumExample basicEnumExample) throws Exception {
		return enumMapper.selectByExample(basicEnumExample);
	}
	
	@Override
	public Map<Object, Object> findEnumObjEnumId() throws Exception {
		Map<Object, Object> map = new HashMap<Object, Object>();
		BasicEnumExample example = new BasicEnumExample();
		example.setOrderByClause("enumid asc");
		List<BasicEnum> list = enumMapper.selectByExample(example); //查询到所有正常数据
		Integer enumId = null;
		for (BasicEnum be : list) {
			enumId = be.getEnumid();
			map.put(enumId, be.getEnumname());
		}

		return map;
	}

	@Override
	public Map<Integer, List<BasicEnum>> findEnumObjParentId() throws Exception {
		BasicEnumExample example = new BasicEnumExample();
		Criteria criteria = example.createCriteria();
		criteria.andDelflagEqualTo(1);
		example.setOrderByClause("enumid asc");
		List<BasicEnum> list = enumMapper.selectByExample(example); //查询到所有正常数据

		Map<Integer, List<BasicEnum>> resultMap = new HashMap<>();
		
		List<Integer> parentIds = new ArrayList<Integer>();
		for (BasicEnum be : list) {
			if (!parentIds.contains(be.getParentid())) {
				parentIds.add(be.getParentid());
			}
		}

		for (Integer parentId : parentIds) {
			List<BasicEnum> children = this.getChildren(list, parentId,null);
			resultMap.put(parentId, children);
		}
		return resultMap;
	}

	
	private List<BasicEnum> getChildren(List<BasicEnum> list, Integer parentId,String planManage) {
		List<BasicEnum> children = new ArrayList<BasicEnum>();
		//计划管理下面的计划 粮食性质去掉储备粮的
		if(planManage!=null && planManage.equals("0")){
			for(BasicEnum be: list){
				//遍历出父id等于参数的id，add进子节点集合  除去储备粮=3045的和父节点是储备粮的
				if (be.getParentid().equals(parentId) && !be.getParentid().equals(3045) && !be.getEnumid().equals(3045)) {
					children.add(be);
				}
			}
		} else {
			for(BasicEnum be: list){
				//遍历出父id等于参数的id，add进子节点集合  
				if (be.getParentid().equals(parentId)) {
					children.add(be);
				}
			}
		}
        return children;
	}

	public void fillTree(List<BasicEnum> allList, List<BasicEnum> childList) {
        if(childList.size()>0){
            for(BasicEnum be : childList) {
                List<BasicEnum> childList1 = this.getChildren(allList, be.getEnumid(),null);
                fillTree(allList, childList1);
                be.setChildren(childList1);
            }
        }
    }

	@Override
	public List<BasicEnum> queryByTree() {
		BasicEnumExample example = new BasicEnumExample();
		Criteria criteria = example.createCriteria();
		criteria.andDelflagEqualTo(1);
		example.setOrderByClause("parentid asc");
		List<BasicEnum> list = enumMapper.selectByExample(example); //查询到所有正常数据
		List<BasicEnum> firstlist = this.getChildren(list, 0,null);
		this.fillTree(list, firstlist);
		return firstlist;
	}

	@Override
	public List<BasicEnum> queryAllChildren(Integer enumid,String planManage) {
		BasicEnumExample example = new BasicEnumExample();
		Criteria criteria = example.createCriteria();
		criteria.andDelflagEqualTo(1);
		example.setOrderByClause("parentid asc, enumId asc");
		List<BasicEnum> list = enumMapper.selectByExample(example); //查询到所有正常数据
		List<BasicEnum> firstlist = this.getChildren(list, enumid,planManage);
		List<BasicEnum> resultList = new ArrayList<>();
		resultList = this.getAllChildren(list, firstlist, resultList);
		return resultList;
	}
	
	private List<BasicEnum> getAllChildren(List<BasicEnum> allList, 
			List<BasicEnum> childList, List<BasicEnum> resultList) {
        resultList.addAll(childList);
        for(BasicEnum be : childList) {
            List<BasicEnum> childList1 = this.getChildren(allList, be.getEnumid(),null);
            if(childList1.size()>0){
                this.getAllChildren(allList, childList1, resultList);
            }
        }
        return resultList;
	}

    /**
     * 枚举导入
     * @param list
     * @throws Exception 
     */
    @Override
    public String importData(List<List<String>> list) {
    	boolean value_flag = false;
    	int len = 0;
    	String msg = "";
        BasicEnum enums = null;
        for (int i = 0; i < list.size(); i++) {
            List<String> revList = list.get(i);
            enums = new BasicEnum();
            enums.setCreatedate(new Date());
            enums.setDelflag(1);
            for (int j = 0; j < revList.size(); j++) {

            	if (j == 0) {
            		value_flag = revList.get(j).matches("[0-9]+");
            		if (!value_flag) {
            			msg = "第 "+(i+1)+" 行的第 1 列的值只能是数字！";
            			return msg;
            		}
            		len = revList.get(j).length();
            		if (len > 11) {
            			msg = "第 "+(i+1)+" 行的第 1 列的值的长度不能超过11！";
            			return msg;
            		}

            		enums.setParentid(Integer.parseInt(revList.get(j).toString()));
            	} else if (j == 1) {
            		len = revList.get(j).length();
            		if (len > 50) {
            			msg = "第 "+(i+1)+" 行的第 2 列的值的长度不能超过50！";
            			return msg;
            		}
            		enums.setEnumcode(revList.get(j));
            	} else if (j == 2) {
            		len = revList.get(j).length();
            		if (len > 50) {
            			msg = "第 "+(i+1)+" 行的第3 列的值的长度不能超过50！";
            			return msg;
            		}
            		enums.setEnumname(revList.get(j));
            	} else if (j == 3) {
            		len = revList.get(j).length();
            		if (len > 50) {
            			msg = "第 "+(i+1)+" 行的第4 列的值的长度不能超过50！";
            			return msg;
            		}
            		enums.setGbcode(revList.get(j));
            	} else if (j == 4) {
            		len = revList.get(j).length();
            		if (len > 255) {
            			msg = "第 "+(i+1)+" 行的第5 列的值的长度不能超过255！";
            			return msg;
            		}
            		enums.setRemark(revList.get(j));
            	}
            }
            enumMapper.insertSelective(enums);
        }

        return msg;
    }

	@Override
	public Map<String, Object> getIdByNameAndParentId(Integer parentId, String enumName, String code) throws Exception {
		Map<String, Object> modelMap = new HashMap<>();

		Integer enumId = 0;
		BasicEnumExample enumExample = new BasicEnumExample();
    	Criteria Criteria = enumExample.createCriteria();
		// 拼接查询条件
		if (null != enumName && !"".equals(enumName)) {
			Criteria.andEnumnameLike("%"+enumName+"%");
		}
		Criteria.andDelflagEqualTo(1); //查询正常数据
		if (null != parentId) {
			Criteria.andParentidEqualTo(parentId); //只查询顶级菜单
		}
		if (StringUtils.isNotBlank(code)) {
			Criteria.andGbcodeLike("%"+code+"%");
		}

		List<BasicEnum> list = enumMapper.selectByExample(enumExample);
		if(list.size()>0){
			enumId = list.get(0).getEnumid();
		}
		modelMap.put("enumId", enumId);
		return modelMap;
	}

	@Override
	public BasicEnum getBasicEnum(Integer parentid, String gbcode) throws Exception {
		BasicEnumExample example = new BasicEnumExample();
		BasicEnumExample.Criteria criteria = example.createCriteria();
		criteria.andParentidEqualTo(parentid);
		criteria.andGbcodeEqualTo(gbcode);
		criteria.andDelflagEqualTo(1);
		List<BasicEnum> list = enumMapper.selectByExample(example);
		BasicEnum emm = null;
		if (null != list && list.size() > 0) {
			emm = list.get(0);
		}
		return emm;
	}

	@Override
	public Map<String, Object> findCondition(Integer parentId, Integer notParentId, Integer notEnumId) {
		Map<String, Integer> param_map = new HashMap<>();
		param_map.put("parentid", parentId);
		if (null != notParentId) {
			param_map.put("notParentid", notParentId);
		}
		if (null != notEnumId) {
			param_map.put("notEnumid", notEnumId);
		}
		List<BasicEnum> list = enumMapper.findCondition(param_map);
		List<BasicEnumVo> voList = new ArrayList<BasicEnumVo>();
    	for (BasicEnum basicEnum : list) {
    		BasicEnumVo basicEnumVo = new BasicEnumVo();
    		basicEnumVo.setId(basicEnum.getEnumid());
    		basicEnumVo.setName(basicEnum.getEnumname());
    		basicEnumVo.setParentid(basicEnum.getParentid());
    		basicEnumVo.setEnumcode(basicEnum.getEnumcode());
    		basicEnumVo.setGbcode(basicEnum.getGbcode());
    		voList.add(basicEnumVo);
    	}
    	Map<String, Object> modelMap = new HashMap<>();
    	modelMap.put("enumList", voList);
    	modelMap.put("enumId", parentId);

        return modelMap;
	}

	
}
