package com.chinaitop.depot.basic.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.basic.mapper.*;
import com.chinaitop.depot.basic.model.*;
import com.chinaitop.depot.basic.model.BasicStorehouseExample.Criteria;
import com.chinaitop.depot.basic.service.BasicKeeperService;
import com.chinaitop.depot.feign.service.RoleInfoFeignService;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;

@Service
public class BasicKeeperServiceImpl implements BasicKeeperService {

	@Resource
	private BasicKeeperMapper mapper;
	
	@Resource
	private BasicStorehouseMapper storehouseMapper;

	@Resource
	private BasicKeeperHouseMapper keepHouseMapper;
	
	@Resource
	private BasicKeeperEducationMapper eduMapper;

	@Resource
	private BasicEnumMapper enumMapper;

	@Resource
	private RoleInfoFeignService roleInfoFeignService;

	@Override
	public void add(BasicKeeper keeper) {
		mapper.insertSelective(keeper);
	}

	@Override
	public void delete(Integer id) {
		mapper.deleteByPrimaryKey(id);
	}

	@Override
	public void update(BasicKeeper keeper) {
		mapper.updateByPrimaryKeySelective(keeper);
	}

	@Override
	public BasicKeeper findByIdParmartKey(Integer id) {
		return mapper.selectByPrimaryKey(id);
	}

	@Override
	public List<BasicKeeper> findCondition(BasicKeeperExample example) {
		return mapper.selectByExample(example);
	}
	
	@Override
	public Map<String, Object> findByKeeperAll(Integer id) {
		Map<String, Object> map = new HashMap<String, Object>();
		BasicKeeper keeper = null;
		
		List<BasicKeeperEducation> xlxwList = new ArrayList<BasicKeeperEducation>(); //学历学位信息1
		List<BasicKeeperEducation> zyjsList = new ArrayList<BasicKeeperEducation>(); //专业技术职称2
		List<BasicKeeperEducation> zyzgList = new ArrayList<BasicKeeperEducation>(); //职业资格及等级3
		List<BasicKeeperEducation> sgzList = new ArrayList<BasicKeeperEducation>(); //上岗证4
		List<BasicKeeperEducation> jllgList = new ArrayList<BasicKeeperEducation>(); //交流轮岗5
		
		if (id != null) {
			//获取保管员基础信息
			keeper = mapper.selectByPrimaryKey(id);
			
			//获取这个保管员可管理的仓房
			BasicKeeperHouseExample storeKeepExample = new BasicKeeperHouseExample();
			BasicKeeperHouseExample.Criteria keepCriteria = storeKeepExample.createCriteria();
			keepCriteria.andKeeperIdEqualTo(id);
			storeKeepExample.setOrderByClause("house_Id asc");
			List<BasicKeeperHouse> kepHouselist = keepHouseMapper.selectByExample(storeKeepExample);
			
			// 将仓房ID插入一个Integer类型的集合，用于转换名称时的条件
			List<Integer> idList = new ArrayList<Integer>();
			if (null != kepHouselist && kepHouselist.size() > 0) {
				for (BasicKeeperHouse bkh : kepHouselist) {
					idList.add(bkh.getHouseId());
				}
			}
			
			// 将仓房ID转换为仓房名称
			if (idList.size() > 0) {
				BasicStorehouseExample storeExample = new BasicStorehouseExample();
				Criteria criteria = storeExample.createCriteria();
				criteria.andOrgIdEqualTo(keeper.getGrainId());
				criteria.andStorehouseIdIn(idList);
				criteria.andDelFlagEqualTo(1);
				List<BasicStorehouse> storelist = storehouseMapper.selectByExample(storeExample);
				if (null != storelist && storelist.size() > 0) {
					String storeName = "";
					for (BasicStorehouse bsh : storelist) {
						storeName += bsh.getStorehouseName() + ",";
					}
					storeName = storeName.substring(0, storeName.length()-1);
					keeper.setHouseId(storeName);
				}
			}
			
			//获取保管员学历、职业等其它数据集合
			BasicKeeperEducationExample example = new BasicKeeperEducationExample();
			BasicKeeperEducationExample.Criteria educationCriteria = example.createCriteria();
			educationCriteria.andKeeperIdEqualTo(id);
			example.setOrderByClause("id,dataType asc");
			List<BasicKeeperEducation> list = eduMapper.selectByExample(example);
			
			if (null != list && list.size() > 0) {
				for (BasicKeeperEducation bke : list) {
					bke.setKeeperId(keeper.getId());
					if (1 == bke.getDatatype()) {
						bke.setDatatype(1);
						xlxwList.add(bke);
					} else if (2 == bke.getDatatype()) {
						bke.setDatatype(2);
						zyjsList.add(bke);
					} else if (3 == bke.getDatatype()) {
						bke.setDatatype(3);
						zyzgList.add(bke);
					} else if (4 == bke.getDatatype()) {
						bke.setDatatype(4);
						sgzList.add(bke);
					} else if (5 == bke.getDatatype()) {
						bke.setDatatype(5);
						jllgList.add(bke);
					}
				}
			}
		} else {
			keeper = new BasicKeeper();
		}

		map.put("keeper", keeper);
		
		
		//如果有一种类型的集合是空的，那么先给new一个空对象
//		if (null == xlxwList || xlxwList.size() == 0) {
//			ekeObje = new BasicKeeperEducation();
//			ekeObje.setKeeperId(keeper.getId());
//			ekeObje.setDatatype(1);
//			xlxwList.add(ekeObje);
//		}
//		if (null == zyjsList || zyjsList.size() == 0) {
//			ekeObje = new BasicKeeperEducation();
//			ekeObje.setKeeperId(keeper.getId());
//			ekeObje.setDatatype(2);
//			zyjsList.add(ekeObje);
//		}
//		if (null == zyzgList || zyzgList.size() == 0) {
//			ekeObje = new BasicKeeperEducation();
//			ekeObje.setKeeperId(keeper.getId());
//			ekeObje.setDatatype(3);
//			zyzgList.add(ekeObje);
//		}
//		if (null == sgzList || sgzList.size() == 0) {
//			ekeObje = new BasicKeeperEducation();
//			ekeObje.setKeeperId(keeper.getId());
//			ekeObje.setDatatype(4);
//			sgzList.add(ekeObje);
//		}
//		if (null == jllgList || jllgList.size() == 0) {
//			ekeObje = new BasicKeeperEducation();
//			ekeObje.setKeeperId(keeper.getId());
//			ekeObje.setDatatype(5);
//			jllgList.add(ekeObje);
//		}

		map.put("xlxwList", xlxwList);
		map.put("zyjsList", zyjsList);
		map.put("zyzgList", zyzgList);
		map.put("sgzList", sgzList);
		map.put("jllgList", jllgList);

		return map;
	}

	@Override
	public Map<String, Object> getUnitStoreKeepList(Integer orgId, Integer id, String libraryType) {
		Map<String, Object> map = new HashMap<String, Object>();

		// 获取当前保管员所在单位下的所有仓房
		BasicStorehouseExample storeExample = new BasicStorehouseExample();
		Criteria criteria = storeExample.createCriteria();
		criteria.andOrgIdEqualTo(orgId);
		criteria.andDelFlagEqualTo(1);
		if(libraryType!="null" && libraryType!="") {
			criteria.andLibraryTypeEqualTo(libraryType);
		}
		List<BasicStorehouse> storelist = storehouseMapper.selectByExample(storeExample);

		// 获取当前保管员在他所在单位所拥有的可管理的仓房权限
		BasicKeeperHouseExample storeKeepExample = new BasicKeeperHouseExample();
		BasicKeeperHouseExample.Criteria keepCriteria = storeKeepExample.createCriteria();
		keepCriteria.andOrgIdEqualTo(orgId);
		keepCriteria.andKeeperIdEqualTo(id);
		List<BasicKeeperHouse> kepHouselist = keepHouseMapper.selectByExample(storeKeepExample);
		
		//设置将已经的有管理权限的的仓房默认选中
		if (null != kepHouselist && kepHouselist.size() > 0) {
			Integer storeId = null;
			for (BasicStorehouse store : storelist) {
				storeId = store.getStorehouseId();
				for (BasicKeeperHouse kepHouse : kepHouselist) {
					if (kepHouse.getHouseId() == storeId || storeId.equals(kepHouse.getHouseId())) {
						store.setDelFlag(5); // 利用这个字段做个标识，5代表是这个仓房有管理权限，要默认选中
					}
				}
			}
			
		}
		
		map.put("storeList", storelist);
		
		return map;
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public void saveKeeperHouse(String selected, Integer bgyId, String userInfo) {
		JSONObject user = null;
		Integer orgId = null;
        Integer userId = null;
        if (null != userInfo && !"".equals(userInfo)) {
        	user = JSONObject.parseObject(userInfo);
        	orgId = Integer.parseInt(user.get("orgId") == null?"":user.get("orgId").toString());
        	userId = Integer.parseInt(user.get("userId") == null?"":user.get("userId").toString());
        }
		//先删掉原来的保管员仓房权限数据
		BasicKeeperHouseExample example = new BasicKeeperHouseExample();
		com.chinaitop.depot.basic.model.BasicKeeperHouseExample.Criteria keepCriteria = example.createCriteria();
		keepCriteria.andKeeperIdEqualTo(bgyId);
		keepCriteria.andOrgIdEqualTo(orgId);
		keepHouseMapper.deleteByExample(example);
		
		String[]checkArray = null;
		if (selected.length() > 2) {
			String sted = selected.substring(1, selected.length() - 1);
			checkArray = sted.split(",");
		}
		
		// 在把新的权限信息插入
		BasicKeeperHouse keperHouse = null;
		if (checkArray != null && checkArray.length > 0) {
			Date date = new Date();
			//UserInfo user = (UserInfo) request.getSession().getAttribute("userInfo");
			for (String hid : checkArray) {
				keperHouse = new BasicKeeperHouse();
				keperHouse.setKeeperId(bgyId);
				keperHouse.setOrgId(orgId);
				keperHouse.setHouseId(Integer.parseInt(hid));
				keperHouse.setCreateId(userId);
				keperHouse.setCreateTime(date);
				keepHouseMapper.insertSelective(keperHouse);
			}
		}
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public void editKeeper(String userInfo, String keeper, 
			String xwxlJson, String zyjsJson, String zyzgJson, String sgzJson, String jllgJson) throws Exception {
		Date date = new Date();
		JSONObject user = null;
		Integer orgId = null;
        Integer userId = null;
        if (null != userInfo && !"".equals(userInfo)) {
        	user = JSONObject.parseObject(userInfo);
        	orgId = Integer.parseInt(user.get("orgId") == null?"":user.get("orgId").toString());
        	userId = Integer.parseInt(user.get("userId") == null?"":user.get("userId").toString());
        }
		// 保存主表数据
		ObjectMapper mappers = new ObjectMapper();
		BasicKeeper basicKeeper = mappers.readValue(keeper, BasicKeeper.class);
		Integer id = null;
		if (basicKeeper.getId() != null) {
			id = basicKeeper.getId();
			basicKeeper.setEditPersonId(userId);
			basicKeeper.setEditDate(date);
			mapper.updateByPrimaryKey(basicKeeper);
			
			//如果由保管员改变到其它部门后，要把他管理的仓房删掉
			int roleId = basicKeeper.getPostType();
			Map<String, Object> roleInfo_map = roleInfoFeignService.selectRoleInfoFindId(roleId);
			String roleName = ObjectUtils.toString(roleInfo_map.get("roleName"), "");
			if (!"保管员".equals(roleName) && !"仓储人员".equals(roleName)) {
				BasicKeeperHouseExample khExample = new BasicKeeperHouseExample();
				BasicKeeperHouseExample.Criteria khCriteria = khExample.createCriteria();
				khCriteria.andKeeperIdEqualTo(id);
				khCriteria.andOrgIdEqualTo(orgId);
				keepHouseMapper.deleteByExample(khExample);
			}
		} else {
			basicKeeper.setGrainId(orgId);
			basicKeeper.setOrgId(orgId);
			basicKeeper.setInputPersonId(userId);
			basicKeeper.setInputDate(date);
			basicKeeper.setDelFlag(1);
			mapper.insertSelective(basicKeeper);
			id = basicKeeper.getId();
		}

		//更新子表数据
		//学历学位信息1
		List<BasicKeeperEducation> xlxwList = mappers.readValue(xwxlJson, new TypeReference<List<BasicKeeperEducation>>(){});
		editEducation(xlxwList, id, basicKeeper.getOrgId(), 1);
		//技能等级2
		List<BasicKeeperEducation> zyjsList = mappers.readValue(zyjsJson, new TypeReference<List<BasicKeeperEducation>>(){});
		editEducation(zyjsList, id, basicKeeper.getOrgId(), 2);
		//职称和荣誉称号3
		List<BasicKeeperEducation> zyzgList = mappers.readValue(zyzgJson, new TypeReference<List<BasicKeeperEducation>>(){});
		editEducation(zyzgList, id, basicKeeper.getOrgId(), 3);
		//上岗证4
		List<BasicKeeperEducation> sgzList = mappers.readValue(sgzJson, new TypeReference<List<BasicKeeperEducation>>(){});
		editEducation(sgzList, id, basicKeeper.getOrgId(), 4);
		//交流轮岗5
		List<BasicKeeperEducation> jllgList = mappers.readValue(jllgJson, new TypeReference<List<BasicKeeperEducation>>(){});
		editEducation(jllgList, id, basicKeeper.getOrgId(), 5);

	}

	/**
	 * 更新保管员证件信息
	 * 
	 * @param edcationList
	 * @param id
	 */
	@Transactional(rollbackFor = Exception.class)
	public void editEducation(List<BasicKeeperEducation> edcationList, Integer id, Integer orgId, Integer datatype) {
		for (BasicKeeperEducation bke : edcationList) {
			bke.setKeeperId(id);
			bke.setDatatype(datatype);
			if (null == bke.getId() || "".equals(bke.getId())) {
				if ("1".equals(datatype) || datatype == 1) {//学历
//					Integer education = bke.getEducation();
//					if (education == null) {
//						continue;
//					}
				} else if ("2".equals(datatype) || datatype == 2) {//技能等级
					String departMent = bke.getDepartment();
					if (departMent == null || "".equals(departMent)) {
						continue;
					}
				} else if ("3".equals(datatype) || datatype == 3) {//职称和荣誉称号
					String departMent = bke.getDepartment();
					if (departMent == null || "".equals(departMent)) {
						continue;
					}
				} if ("4".equals(datatype) || datatype == 3) {//上岗证
					String departMent = bke.getDepartment();
					if (departMent == null || "".equals(departMent)) {
						continue;
					}
				} else if ("5".equals(datatype) || datatype == 5) {//交流轮岗
					String fzywlx = bke.getFzywlx();
					if (fzywlx == null) {
						continue;
					}
				}
				bke.setOrgId(orgId);
				eduMapper.insertSelective(bke);
			} else {
				eduMapper.updateByPrimaryKey(bke);
			}
		}
	}

	/**
	 * 根据仓房id获取到仓管员信息
	 * @param houseId
	 * @return
	 */
	@Override
	public List<BasicKeeper> getKepperByHouseId(Integer houseId) {
		BasicKeeperHouseExample example = new BasicKeeperHouseExample();
		BasicKeeperHouseExample.Criteria criteria = example.createCriteria();
		criteria.andHouseIdEqualTo(houseId);
		//example.setDistinct(true);
		List<BasicKeeperHouse> keepHouseList = keepHouseMapper.selectByExample(example);
		List<Integer> list = new ArrayList<Integer>();
		if (null != keepHouseList && keepHouseList.size() > 0) {
			for (BasicKeeperHouse k : keepHouseList) {
				list.add(k.getKeeperId());
			}
		}
		List<BasicKeeper> keeperList = new ArrayList<BasicKeeper>();
		if (list != null && list.size() > 0) {
			BasicKeeperExample keeperExample = new BasicKeeperExample();
			BasicKeeperExample.Criteria kcriteria = keeperExample.createCriteria();
			kcriteria.andIdIn(list);
			keeperList = mapper.selectByExample(keeperExample);
		}
		return keeperList;
	}

	/**
	 * 根据移交人的id更新保管员的仓号 【由于业务变更该方法已经不用  暂时留着】
	 * @param houseId
	 * @param transferId
	 */
	@Override
	public void removeHouseKeeperByTransferId(Integer houseId, Integer transferId) {
		/**
		 * ①根据transferId得到该保管员，并且得到该保管员目前所管理的仓号
		 * ②得到该保管员所管理的仓号和要移交的仓号对比  移除掉要移交的仓号
		 * ③进行更新
		 */

		//①根据transferId得到该保管员
		/*BasicKeeper keeper=this.findKeeperHouseByUserId(transferId);
        String houseIds=keeper.getHouseId();
		String[] houses=houseIds.split(",");
        String houseIId=String.valueOf(houseId);
		//②得到该保管员所管理的仓号和要移交的仓号对比  移除掉要移交的仓号
		List<String> list = new ArrayList<String>();
		try {
			for (int i=0;i<houses.length;i++){
				if(!houses[i].equals(houseIId)){
					list.add(houses[i]);
				}
			}
			StringBuffer sb = new StringBuffer();
			for (String s : list){
				sb.append(s).append(",");
			}
			keeper.setHouseId(sb.substring(0,sb.length()-1).toString());

			//③进行更新
			mapper.updateByPrimaryKey(keeper);
		}catch (Exception ex){
			ex.printStackTrace();
		}*/
	}
	//根据移交人id获取对应的保管员信息
    @Override
	public BasicKeeper findKeeperHouseByUserId(Integer userId,Integer roleId) {
		//BasicEnum basicEnum= enumMapper.selectByPrimaryKey(5417);

		BasicKeeperExample keeperExample = new BasicKeeperExample();
		BasicKeeperExample.Criteria criteria = keeperExample.createCriteria();
		criteria.andUserIdEqualTo(userId);
		criteria.andDelFlagEqualTo(1);
		keeperExample.setOrderByClause("id desc");
		if(roleId != null){
			criteria.andPostTypeEqualTo(roleId);
		}
		List<BasicKeeper> keeperList = mapper.selectByExample(keeperExample);
		BasicKeeper keeper = null;
		if (null != keeperList && keeperList.size() > 0) {
			keeper = keeperList.get(0);
		}
		return keeper;
	}

	/**
	 * 根据接收人的id更新保管员的仓号【由于业务变更该方法已经不用  暂时留着】
	 * @param houseId
	 * @param receiveId
	 */
	@Override
	public void addHouseKeeperbyReceiveId(Integer houseId, Integer receiveId) {
		/**
		 * ①查找对应的保管员  和 对应的仓房的id
		 * ②拼接接收到的仓号
		 * ③更新
		 */

		//①查找对应的保管员  和 对应的仓房的id
		/*BasicKeeper keeper=this.findKeeperHouseByUserId(receiveId);
		String houseIds=keeper.getHouseId();
		String[] houses=houseIds.split(",");
		String houseIId=String.valueOf(houseId);
		//②得到该保管员所管理的仓号和要移交的仓号对比  移除掉要移交的仓号
		List<String> list = new ArrayList<String>();
		try {
			for (int i=0;i<houses.length;i++){
				if(!houses[i].equals(houseIId)){
					list.add(houses[i]);
				}
			}
			list.add(houseIId);//将当前的仓号放进去
			StringBuffer sb = new StringBuffer();
			for (String s : list){
				sb.append(s).append(",");
			}
			keeper.setHouseId(sb.substring(0,sb.length()-1).toString());

			//③进行更新
			mapper.updateByPrimaryKey(keeper);
		}catch (Exception ex){
			ex.printStackTrace();
		}*/

	}

	@Override
	public List<BasicKeeper> findBarn(Map<String,Object> map) {
		return mapper.selectBarn(map);
	}

	@Override
	public List<BasicKeeper> getKeeperListByNameAndHouseId(String name, Integer storehouseId) {
		return mapper.getKeeperListByNameAndHouseId(name,storehouseId);
	}

	@Override
	public String getKeeperNames(List<Integer> keep_list) {

		String keeperNames = "";

		BasicKeeperExample keeperExample = new BasicKeeperExample();
		BasicKeeperExample.Criteria criteria = keeperExample.createCriteria();
		criteria.andIdIn(keep_list);
		List<BasicKeeper> list = mapper.selectByExample(keeperExample);
		
		if (null != list && list.size() > 0) {
			for (BasicKeeper keeper : list) {
				keeperNames = keeperNames + keeper.getName() + ",";
			}

			keeperNames = keeperNames.substring(0, keeperNames.length()-1);

		}

		return keeperNames;
	}

}
