package com.chinaitop.depot.basic.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.basic.mapper.BasicEnumMapper;
import com.chinaitop.depot.basic.mapper.BasicStorehouseMapper;
import com.chinaitop.depot.basic.mapper.BasicTankMapper;
import com.chinaitop.depot.basic.mapper.BasicWarehouseMapper;
import com.chinaitop.depot.basic.model.BasicEnum;
import com.chinaitop.depot.basic.model.BasicEnumExample;
import com.chinaitop.depot.basic.model.BasicStorehouse;
import com.chinaitop.depot.basic.model.BasicStorehouseExample;
import com.chinaitop.depot.basic.model.BasicTank;
import com.chinaitop.depot.basic.model.BasicTankExample;
import com.chinaitop.depot.basic.model.BasicStorehouseExample.Criteria;
import com.chinaitop.depot.basic.model.BasicWarehouse;
import com.chinaitop.depot.basic.model.BasicWarehouseExample;
import com.chinaitop.depot.basic.service.BasicEnumService;
import com.chinaitop.depot.basic.service.BasicKeeperHouseService;
import com.chinaitop.depot.basic.service.BasicKeeperService;
import com.chinaitop.depot.basic.service.BasicStorehouseService;
import com.chinaitop.depot.basic.service.BasicTankService;
import com.chinaitop.depot.basic.service.BasicWarehouseService;
import com.chinaitop.depot.system.mapper.OrgInfoMapper;
import com.chinaitop.depot.system.model.OrgInfo;
import com.chinaitop.depot.utils.BusinessUtils;
import com.chinaitop.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.transaction.annotation.Transactional;

@Service
@SuppressWarnings("all")
public class BasicStorehouseServiceImpl implements BasicStorehouseService {

	@Resource
	private BasicStorehouseMapper basic;

	@Resource
	private BasicWarehouseMapper wareMapper;
	
	@Resource
	private BasicWarehouseService warehouseService;

	@Resource
	private BasicEnumMapper enumMapper;

	@Resource
	private BasicEnumService basicEnumService;

	@Resource
	private BasicKeeperHouseService keeperHouseService;

	@Resource
	private BasicKeeperService keeperService;

	@Resource
	private BasicTankMapper basicTankMapper;

	@Resource
	private OrgInfoMapper orgInfoMapper;

	@Override
	public void addBasicStorehouse(BasicStorehouse basicStorehouse) throws Exception {
		basic.insert(basicStorehouse);
	}

	@Override
	public void removeBasicStorehouse(Integer id) throws Exception {
		basic.deleteByPrimaryKey(id);
	}

	@Override
	public void updateBasicStorehouse(BasicStorehouse basicStorehouse) throws Exception {
		basic.updateByPrimaryKey(basicStorehouse);
	}

	@Override
	public BasicStorehouse findByPrimary(Integer id) throws Exception {
		return basic.selectByPrimaryKey(id);
	}

	@Override
	public List<BasicStorehouse> findBasicStorehouse(BasicStorehouseExample basicStorehouseExample) throws Exception {
		return basic.selectByExample(basicStorehouseExample);
	}

	@Override
	public List<BasicStorehouse> findBasicStorehouseNew(Map<String, Object> map) throws Exception {
		return basic.selectByExampleNew(map);
	}

	@Override
	public int count(BasicStorehouseExample basicStorehouseExample) throws Exception {
		return basic.countByExample(basicStorehouseExample);
	}

	@Override
	public Map<String, Object> getStorehouseData(Integer orgId, String libraryType) throws Exception {
		Map<String, Object> modelMap = new HashMap<String, Object>();

		/* 包含所有有效的仓房和油罐信息的下拉对象  */
		modelMap.put("house_and_tank_List", getStorehouseList(orgId, libraryType, null));

		/* 包含所有有效的仓房信息的下拉对象  */
		modelMap.put("houseList", getStorehouseList(orgId, libraryType, "0"));

		/* 包含所有有效的油罐信息的下拉对象  */
		modelMap.put("tankList", getStorehouseList(orgId, libraryType, "1"));

		/* 按ID来封装的包含所有仓房和油罐(有仓房的详细详细，油罐只有ID、code和name) */
		modelMap.put("houseObj", getStorehouseObj(orgId, libraryType, null));

		/* 按code来封装的包含所有仓房和油罐(有仓房的详细详细，油罐只有ID、code和name) */
		modelMap.put("houseCodeObj", getStorehouseCodeObj(orgId, libraryType, null));

		/* 包含所有油罐信息的下拉对象  */
		modelMap.put("tankObj", getTankObj(orgId, libraryType));

		return modelMap;
	}
	
	private Map<Integer, Object> getTankObj(Integer orgId, String libraryType) {
		Map<String, Object> map = new HashMap<>();
		List<BasicTank> tankObj = null;
		try {
			if (ParameterUtil.isnotnull(libraryType)) {
				map.put("libraryType", libraryType);
			}else if(ParameterUtil.isnull(libraryType)){
				map.put("libraryType", "0");//如果不传值则默认查询主库数据，不查询代储库数据
			}
			if (ParameterUtil.isnotnull(orgId)) {
				map.put("orgId", orgId);
			}
			tankObj = basicTankMapper.selectTankAndHw(map); //获取当前单位所有的仓房和油罐数据
		} catch (Exception e) {
			System.out.println(e.getMessage());
		}
		Map<Integer, Object> objMap = new HashMap<Integer, Object>();
		for (int i = 0; i < tankObj.size(); i++) {
			objMap.put(Integer.parseInt(tankObj.get(i).getId()), tankObj.get(i));
		}
		return objMap;
	}

	private List<BasicStorehouse> getStorehouseList(Integer orgId, String libraryType, String datatype) {
		List<BasicStorehouse> list = null;
		BasicStorehouseExample example = new BasicStorehouseExample();
		Criteria criteria = example.createCriteria();
		try {
			example.setOrderByClause("storehouse_id asc");
			if (ParameterUtil.isnotnull(orgId)) { 
				criteria.andOrgIdEqualTo(orgId);
			}
			if (ParameterUtil.isnotnull(libraryType)) {
				criteria.andLibraryTypeEqualTo(libraryType);
			}else if(ParameterUtil.isnull(libraryType)){
				criteria.andLibraryTypeEqualTo("0");//如果不传值则默认查询主库数据，不查询代储库数据
			}
			if (null != datatype && !"".equals(datatype)) {
				criteria.andDatatypeEqualTo(datatype);
			}
			criteria.andDelFlagEqualTo(1); // 查询正常数据
			list = basic.selectByExample(example); //获取当前单位下的所有有效仓房和油罐的下拉列表数据
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			return list;
		}
	}

	/**
	 * 获取当前单位下所有仓房和油罐数据(全局接口，不可随便修改)
	 *
	 * @param orgId
	 * @return
	 */
	private Map<Integer, Object> getStorehouseObj(Integer orgId,String libraryType, String datatype) {
		BasicStorehouseExample example = new BasicStorehouseExample();
		Criteria criteria = example.createCriteria();
		List<BasicStorehouse> houseObj = null;
		try {
			example.setOrderByClause("storehouse_id asc");

			if (ParameterUtil.isnotnull(libraryType)) {
				criteria.andLibraryTypeEqualTo(libraryType);
			}else if(ParameterUtil.isnull(libraryType)){
				criteria.andLibraryTypeEqualTo("0");//如果不传值则默认查询主库数据，不查询代储库数据
			}
			if (ParameterUtil.isnotnull(orgId)) {
				criteria.andOrgIdEqualTo(orgId);
			}
			if (null != datatype && !"".equals(datatype)) {
				criteria.andDatatypeEqualTo(datatype);
			}
			/*criteria.andDelFlagEqualTo(1); // 查询正常数据
*/			houseObj = basic.selectByExample(example); //获取当前单位所有的仓房和油罐数据
		} catch (Exception e) {
			e.printStackTrace();
		}
		Map<Integer, Object> objMap = new HashMap<Integer, Object>();
		for (BasicStorehouse obj : houseObj) {
			objMap.put(obj.getStorehouseId(), obj);
		}
		return objMap;
	}

	/**
	 * 获取当前单位下所有仓房数据-仓房编码(全局接口，不可随便修改)
	 *
	 * @param depotId
	 * @return
	 */
	private Map<String, Object> getStorehouseCodeObj(Integer orgId, String libraryType, String datatype) {
		BasicStorehouseExample example = new BasicStorehouseExample();
		Criteria criteria = example.createCriteria();
		List<BasicStorehouse> houseObj = null;
		try {
			example.setOrderByClause("storehouse_id asc");

			if (ParameterUtil.isnotnull(libraryType)) {
				criteria.andLibraryTypeEqualTo(libraryType);
			}else if(ParameterUtil.isnull(libraryType)){
				criteria.andLibraryTypeEqualTo("0");//如果不传值则默认查询主库数据，不查询代储库数据
			}
			if (ParameterUtil.isnotnull(orgId)) {
				criteria.andOrgIdEqualTo(orgId);
			}
			if (null != datatype && !"".equals(datatype)) {
				criteria.andDatatypeEqualTo(datatype);
			}
			//criteria.andDelFlagEqualTo(1); // 查询正常数据
			houseObj = basic.selectByExample(example); //获取当前单位所有的仓房数据
		} catch (Exception e) {
			e.printStackTrace();
		}
		Map<String, Object> objMap = new HashMap<>();
		for (BasicStorehouse obj : houseObj) {
			objMap.put(obj.getStorehouseCode(), obj);
		}
		return objMap;
	}

	@Override
	public String importData(List<List<String>> list, JSONObject user) {

		Integer orgId = null;
		String orgName = "";
		if (null != user) {
			orgId = Integer.parseInt(user.get("orgId") == null?"":user.get("orgId").toString());
			orgName = user.get("orgName") == null?"":user.get("orgName").toString();
		}

		String uuid = null;
		Date date = new Date();
		Map<String, Integer> map = new HashMap<String, Integer>();
		BasicStorehouse storehouse = null;
		BasicWarehouse warehouse = null;
		String msg = "";//消息
		boolean value_flag = false;
		int len = 0;//长度
		//根据字典名字查询字典编号
		BasicEnumExample enumExample = new BasicEnumExample();
		BasicEnumExample.Criteria Criteria = enumExample.createCriteria();
		List<BasicEnum> basicEnums;

		for (int i = 0; i < list.size(); i++) {
			List<String> revList = list.get(i);
			uuid = UUID.randomUUID().toString();

			for (int j = 0; j < revList.size(); j++) {
				switch(j) {
					case 0://仓房编号
						if (ParameterUtil.isnotnull(revList.get(j))) {
							len = revList.get(j).length();
							if (len > 50) {
								msg = "第 "+(i+1)+" 行第 1 列的值的长度不能超过50！";
								return msg;
							}

							Integer mapKey = map.get(revList.get(j));
							if (mapKey == null) {
								storehouse = new BasicStorehouse();
								map.put(revList.get(j), null);
								storehouse.setStorehouseCode(revList.get(j));
							}
						}
						break;
					case 1://仓房名称
						if (storehouse != null) {
							len = revList.get(j).length();
							if (len > 50) {
								msg = "第 "+(i+1)+" 行第 2 列的值的长度不能超过50！";
								return msg;
							}
							storehouse.setStorehouseName(revList.get(j));
						}
						break;
					case 2://仓房类型
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							enumExample.clear();
							Criteria = enumExample.createCriteria();
							Criteria.andEnumnameEqualTo(revList.get(j));
							basicEnums = enumMapper.selectByExample(enumExample);
							if(basicEnums.size() == 0){
								msg = "第 "+(i+1)+" 行第 3 列的值不正确，请查找后在导入！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 11) {
								msg = "第 "+(i+1)+" 行第 3 列的值的长度不能超过11！";
								return msg;
							}
							storehouse.setStorehouseType(basicEnums.get(0).getEnumid());
						}
						break;
					case 3://设计仓容(吨)
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 4 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 4 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setDesignCapacity(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 4://实际仓容(吨)
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 5 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 5 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setActualCapacity(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 5://通风方式
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							enumExample.clear();
							Criteria = enumExample.createCriteria();
							Criteria.andEnumnameEqualTo(revList.get(j));
							basicEnums = enumMapper.selectByExample(enumExample);
							if(basicEnums.size() == 0){
								msg = "第 "+(i+1)+" 行第 6 列的值不正确，请查找后在导入！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 100) {
								msg = "第 "+(i+1)+" 行第 6 列的值的长度不能超过100！";
								return msg;
							}
							storehouse.setDrafttype(basicEnums.get(0).getEnumid());
						}
						break;
					case 6://保管方式
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							enumExample.clear();
							Criteria = enumExample.createCriteria();
							Criteria.andEnumnameEqualTo(revList.get(j));
							basicEnums = enumMapper.selectByExample(enumExample);
							if(basicEnums.size() == 0){
								msg = "第 "+(i+1)+" 行第 7 列的值不正确，请查找后在导入！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 100) {
								msg = "第 "+(i+1)+" 行第 7 列的值的长度不能超过100！";
								return msg;
							}
							storehouse.setKeepingWay(basicEnums.get(0).getEnumid());
						}
						break;
					case 7://装粮线高度(m)
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 8 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 8 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setGrainHeigth(new BigDecimal(revList.get(j)));
						}
						break;
					/*case 8://保管员 注：liangs 2019/07/08 注掉保管员列
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							len = revList.get(j).length();
							if (len > 50) {
								msg = "第 "+(i+1)+" 行第 9 列的值的长度不能超过50！";
								return msg;
							}
							storehouse.setDutystoreman(revList.get(j));
						}
						break;*/
					case 8://仓房状态
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							enumExample.clear();
							Criteria = enumExample.createCriteria();
							Criteria.andEnumnameEqualTo(revList.get(j));
							basicEnums = enumMapper.selectByExample(enumExample);
							if(basicEnums.size() == 0){
								msg = "第 "+(i+1)+" 行第 9 列的值不正确，请查找后在导入！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 11) {
								msg = "第 "+(i+1)+" 行第 9 列的值的长度不能超过11！";
								return msg;
							}
							storehouse.setStorehouseState(basicEnums.get(0).getEnumid());
						}
						break;
					case 9://交付使用日期
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							if(!ParameterUtil.stringIsTime(revList.get(j))){
								msg = "第 "+(i+1)+" 行第 10 列的值不属于时间，请确认后再提交！";
								return msg;
							}
							storehouse.setUsedate(ParameterUtil.string2datetime(revList.get(j)));
						}
						if (storehouse != null) {
							storehouse.setUuid(uuid);
							storehouse.setDelFlag(1);
							storehouse.setCreatedate(date);
							storehouse.setOrgId(orgId);
						}
						break;
					case 10://货位编号
						if (ParameterUtil.isnotnull(revList.get(j))) {
							len = revList.get(j).length();
							if (len > 50) {
								msg = "第 "+(i+1)+" 行第 11 列的值的长度不能超过50！";
								return msg;
							}

							warehouse = new BasicWarehouse();
							warehouse.setWarehouseCode(revList.get(j));
						}
						break;
					case 11://货位名称
						if (ParameterUtil.isnotnull(revList.get(j))) {
							len = revList.get(j).length();
							if (len > 50) {
								msg = "第 "+(i+1)+" 行第 12 列的值的长度不能超过50！";
								return msg;
							}
							if (warehouse != null) {
								warehouse.setWarehouseName(revList.get(j));
							}
						}
						break;
					case 12://货位容量(吨)
						if (ParameterUtil.isnotnull(revList.get(j))) {
							len = revList.get(j).length();
							if (len > 50) {
								msg = "第 "+(i+1)+" 行第 13 列的值的长度不能超过50！";
								return msg;
							}
							if (warehouse != null) {
								warehouse.setWarehouseCapacity(new BigDecimal(revList.get(j)));
							}
						}
						if (warehouse != null) {
							warehouse.setDelFlag(1);
							warehouse.setCreatedate(date);
							warehouse.setOrgId(orgId);
							warehouse.setWarehouseStatus(2963); //添加时默认货位状态为空仓
						}
						break;
					case 13:
						if (ParameterUtil.isnotnull(revList.get(j))) {
							//插入仓房信息
							if (storehouse != null) {
								storehouse.setLibraryType(revList.get(j));
							}
							if (warehouse != null) {
								warehouse.setLibraryType(revList.get(j));
							}
						}
						break;
					case 14:
						//if (ParameterUtil.isnotnull(revList.get(j))) {
							Map<String,Object> depotMap = new HashMap<String, Object>();
							if ("1".equals(storehouse.getLibraryType())) {
								depotMap.put("agentDepotName",revList.get(j));
								depotMap = basic.getAgentDepotId(depotMap);
								if(ParameterUtil.isnull(depotMap)){
									msg = "第 "+(i+1)+" 行第 15 列的值的不正确，请查询后再添加！";
									return msg;
								}
							}
							//插入仓房信息
							if (storehouse != null) {
								if(ParameterUtil.isequal("1",storehouse.getLibraryType())){
									storehouse.setDepotId(Integer.parseInt(depotMap.get("id").toString()));
									storehouse.setDepotName(revList.get(j));
								}else{
									storehouse.setDepotId(orgId);
									storehouse.setDepotName(orgName);
								}
								//校验仓房编码不可重复
								boolean flag = uniqueParityCheck("house", storehouse.getStorehouseCode(), orgId, null);
								if (!flag) {
									msg = "第 "+(i+1)+" 行的仓房编码已在数据库存在！";
									return msg;
								}
								basic.insert(storehouse);
								map.put(storehouse.getStorehouseCode(), storehouse.getStorehouseId());
							}
							if (warehouse != null) {
								if(ParameterUtil.isequal("1",warehouse.getLibraryType())){
									warehouse.setDepotId(Integer.parseInt(depotMap.get("id").toString()));
									warehouse.setDepotName(revList.get(j));
								}else{
									warehouse.setDepotId(orgId);
									warehouse.setDepotName(orgName);
								}
								//校验货位编码不可重复
								boolean flag = uniqueParityCheck("ware", revList.get(j), orgId, map.get(revList.get(0)));
								if (!flag) {
									msg = "第 "+(i+1)+" 行的仓房编码已在数据库存在！";
									return msg;
								}
								warehouse.setStorehouseId(map.get(revList.get(0)));
								wareMapper.insert(warehouse);
							}
						//}
						storehouse = null;
						warehouse = null;
						break;
					default :
						break;

				}

			}

		}
		return msg;
	}

	/**
	 * 校验仓房或货位的编码是否存在
	 * 
	 * @param type 标识符
	 * @param code 编码值
	 * @param orgId 单位ID
	 * @param houseId 仓房ID
	 * @return
	 */
	private boolean uniqueParityCheck(String type, String code, Integer orgId, Integer houseId) {
		boolean flag = false;
		
		if ("house".equals(type)) {
			BasicStorehouseExample example = new BasicStorehouseExample();
			Criteria criteria = example.createCriteria();
			criteria.andOrgIdEqualTo(orgId);
			criteria.andStorehouseCodeEqualTo(code);
			criteria.andLibraryTypeEqualTo("0");
			List<BasicStorehouse> list = basic.selectByExample(example);
			if (null == list || list.size() == 0) {
				flag = true;
			}
		}
		if ("ware".equals(type)) {
			BasicWarehouseExample example = new BasicWarehouseExample();
			BasicWarehouseExample.Criteria criteria = example.createCriteria();
			criteria.andOrgIdEqualTo(orgId);
			criteria.andWarehouseCodeEqualTo(code);
			criteria.andStorehouseIdEqualTo(houseId);
			criteria.andLibraryTypeEqualTo("0");
			List<BasicWarehouse> list = wareMapper.selectByExample(example);
			if (null == list || list.size() == 0) {
				flag = true;
			}
		}
		
		return flag;
	}

	@Override
	public String getStorehouseKeeper(Integer id, Integer orgId, boolean flag) {
		String keeperNames = "";

		/* 获取这个仓房的所有保管员的员工ID */
		List<Integer> keep_list = keeperHouseService.getKeeperId(orgId, id);

		//2、然后把这些人的翻译过来，展示出来
		if (null != keep_list && keep_list.size() > 0) {
			keeperNames = keeperService.getKeeperNames(keep_list);
			if (flag) {
				if (keeperNames.length() > 7) {
					keeperNames = keeperNames.substring(0, 7) + "...";
				}
			}
		}

		return keeperNames;
	}
	

	@Override
	public Map<String, Object> getThreeTempCheckList(Integer orgId) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		Map<String, Object> map = new HashMap<String, Object>();
		List<BasicStorehouse> houselist = null;
		try {
			if (ParameterUtil.isnotnull(orgId)) {
				map.put("orgId", orgId);
			}
			map.put("libraryType", 0);//默认查询主库数据，不查询代储库数据
			map.put("delFlag", 1);//查询正常数据
			houselist = basic.getThreeTempCheckList(map); //获取当前单位下的所有有效数据
		} catch (Exception e) {
			e.printStackTrace();
		}
		modelMap.put("houseList", houselist);
		return modelMap;
	}

	@Override
	public BasicStorehouse getStoreDataByHouseId(int houseId) {
		// TODO Auto-generated method stub
		return basic.getStoreDataByHouseId(houseId);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public Map<String, Object> saveOrUpdate(HttpServletRequest request, String storehouseJson, String warehouseJson, String userInfo) throws Exception {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		JSONObject user = null;
		JSONObject org = null;
		Integer orgId = null;
		String userName = "";
		if (null != userInfo && !"".equals(userInfo)) {
			user = JSONObject.parseObject(userInfo);
			orgId = Integer.parseInt(user.get("orgId") == null?"":user.get("orgId").toString());
			userName = user.get("username") == null?"":user.get("username").toString();
		}

		//获取单位信息
		String orgInfo = ObjectUtils.toString(request.getSession().getAttribute("orgInfo"),"");
		String dwbm = "";
		if (null != orgInfo && !"".equals(orgInfo)) {
			org = JSONObject.parseObject(orgInfo);
			dwbm = org.get("creditCode") == null?"":org.get("creditCode").toString();
		}

		Date date = new Date();

		// JSON字符串转对象
		ObjectMapper mapper = new ObjectMapper();
		BasicStorehouse basicStorehouse = (BasicStorehouse) mapper.readValue(storehouseJson, BasicStorehouse.class);
		basicStorehouse.setDelFlag(1);
		
		String cfbm = "";//仓房编码
		String ajbm = "";//廒间编码

		if (!"".equals(basicStorehouse.getStorehouseCode())) {
			cfbm = BusinessUtils.setBZcfandygbm(dwbm, basicStorehouse.getStorehouseCode(), "0", orgId+"");
			ajbm = BusinessUtils.setBZajbm(cfbm, basicStorehouse.getStorehouseType()+"", "0");
			basicStorehouse.setCfbm(cfbm.trim());
			basicStorehouse.setAjbm(ajbm.trim());
		}
		if (basicStorehouse.getStorehouseId() == null) {
			String uuid = UUID.randomUUID().toString();
			//String uuid = UUID.randomUUID().toString().replaceAll("-", "");
			basicStorehouse.setUuid(uuid);

			if(!ParameterUtil.isequal(basicStorehouse.getLibraryType(),"1")){
				basicStorehouse.setDepotId(orgId);
			}
			basicStorehouse.setOrgId(orgId);
			basicStorehouse.setCreatename(userName);
			basicStorehouse.setCreatedate(date);
			basicStorehouse.setDatatype("0");

			basic.insert(basicStorehouse);
		} else {
			basicStorehouse.setDatatype("0");
			basicStorehouse.setDutystoreman(null);
			basicStorehouse.setUpdatename(userName);
			basicStorehouse.setUpdatedate(date);

			basic.updateByPrimaryKey(basicStorehouse);
		}

		//更新货位数据
		warehouseService.saveOrUpdate(basicStorehouse, warehouseJson);

		//更新单位表仓房数、油罐数、有效仓容、有效罐容
		editOrgChNum(orgId);
		modelMap.put("status", "success");

		return modelMap;
	}
	
	@Override
	public void editOrgChNum(Integer orgId) throws Exception {
		//查询当前单位仓房数
		BasicStorehouseExample cf_example = new BasicStorehouseExample();
		BasicStorehouseExample.Criteria cf_criteria = cf_example.createCriteria();
		cf_criteria.andOrgIdEqualTo(orgId);
		cf_criteria.andLibraryTypeEqualTo("0");
		cf_criteria.andDelFlagEqualTo(1);
		cf_criteria.andDatatypeEqualTo("0");
		int ch_count = basic.countByExample(cf_example);
		
		//查询当前单位的油罐数
		BasicTankExample yg_example = new BasicTankExample();
		BasicTankExample.Criteria yg_criteria = yg_example.createCriteria();
		yg_criteria.andOrgIdEqualTo(orgId);
		yg_criteria.andLibraryTypeEqualTo("0");
		yg_criteria.andDelFlagEqualTo(1);
		int yg_count = basicTankMapper.countByExample(yg_example);

		//查询当前单位仓房总实际容量和油罐总实际容量
		Map<String, Object> rl_map = basic.queryCrAndgw(orgId);

		//更新当前单位下仓房数、油罐数数、有效仓房、有效罐容
		Map<String, Object> map = new HashMap<String, Object>();
		map.put("orgId", orgId);
		map.put("cf_count", ch_count);
		map.put("yg_count", yg_count);
		map.put("cr_count", rl_map.get("cr_count"));
		map.put("gr_count", rl_map.get("gr_count"));

		basic.editOrgCfAndHwNum(map);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public Map<String, String> saveOrUpdateSptStorehouseData(String datas) throws Exception {
		Map<String, String> resultMap = new HashMap<>();
		BasicStorehouse storehouse = null;
		List<BasicWarehouse> warehouse_list = null;
		Map<String, String> isadd_map = null;

		JSONObject obj = null;
		JSONArray hwarray = null;
		JSONArray cmarray = null;

        if (StringUtils.isNotBlank(datas)) {
        	obj = JSONObject.parseObject(datas);
        	
        	//货位数据
        	String hwstring = obj.getString("hwxxsjyVOList");
    		if (StringUtils.isNotBlank(hwstring)) {
    			hwarray = JSON.parseArray(hwstring);
    			if (hwarray.size() == 0) {
    				resultMap.put("status", "error");
    	        	resultMap.put("msg", "至少要有一条货位数据!");
    	        	return resultMap;
    			}
    		} else {
    			resultMap.put("status", "error");
	        	resultMap.put("msg", "至少要有一条货位数据!");
	        	return resultMap;
    		}
    		
    		//仓门数据
        	String cmstring = obj.getString("warehouseDoorVOList");
    		if (StringUtils.isNotBlank(cmstring)) {
    			cmarray = JSON.parseArray(cmstring);
    			if (cmarray.size() == 0) {
    				resultMap.put("status", "error");
    	        	resultMap.put("msg", "至少要有一条仓门数据!");
    	        	return resultMap;
    			}
    		} else {
    			resultMap.put("status", "error");
	        	resultMap.put("msg", "至少要有一条仓门数据!");
	        	return resultMap;
    		}
        } else {
        	resultMap.put("status", "error");
        	resultMap.put("msg", "所传的数据串是空的!");
        	return resultMap;
        }
        
        Map<String, Object> check = dataCheck(obj, hwarray, cmarray);
        String msg = check.get("msg").toString();
        if (msg.length() == 0) {
        	storehouse = (BasicStorehouse)check.get("storehouse");
        	warehouse_list = (List<BasicWarehouse>) check.get("ware_list");
        	isadd_map = (Map<String, String>) check.get("isadd_map");

        	//持久化仓房表的数据
        	if (null == storehouse.getStorehouseId()) {
        		basic.insert(storehouse);
        	} else {
        		basic.updateByPrimaryKey(storehouse);
        	}

        	//持久化货位数据
        	for (int i = 0; i < warehouse_list.size(); i++) {
        		if ("true".equals(isadd_map.get(warehouse_list.get(i).getSptDataid()))) {
        			warehouse_list.get(i).setStorehouseId(storehouse.getStorehouseId());
        			wareMapper.insertSelective(warehouse_list.get(i));
        		} else {
        			wareMapper.updateByPrimaryKeySelective(warehouse_list.get(i));
        		}
        	}

			resultMap.put("status", "success");
        	resultMap.put("msg", "操作成功");
		} else {
			resultMap.put("status", "error");
        	resultMap.put("msg", msg);
		}
        
		return resultMap;
	}

	/**
	 * 校验市平台传过来的油罐数据
	 * @param obj 原数据object
	 * @param hwarray 货位数据
	 * @param cmarray 仓门数据
	 * @return
	 * @throws Exception
	 */
	public Map<String, Object> dataCheck(JSONObject obj, JSONArray hwarray, JSONArray cmarray) throws Exception {

		Map<String, Object> map = new HashMap<>();
		StringBuffer sbf = new StringBuffer(100);

		BasicStorehouse storehouse = new BasicStorehouse();
		List<BasicWarehouse> ware_list = new ArrayList<>();

		Integer orgId = null;
		String orgName = null;
		BigDecimal zj = null;

		//库区标准编码
    	String kqdm = obj.getString("kqdm");
    	if (StringUtils.isNotBlank(kqdm)) {
    		OrgInfo orgInfo = orgInfoMapper.selectByPrimaryKey(kqdm.trim());
        	if (null != orgInfo && !"".equals(orgInfo)) {
        		orgId = orgInfo.getOrgId();
        		orgName = orgInfo.getOrgName();
        		storehouse.setDepotId(orgInfo.getOrgId());
        		storehouse.setOrgId(orgInfo.getOrgId());
        		storehouse.setOrgName(orgName);
        		storehouse.setDepotName(orgInfo.getOrgName());
        		storehouse.setDatatype("0");
        	} else {
        		sbf.append("kqdm有误;");
        		String msg = sbf.toString();
        		map.put("msg", msg);
        		return map;
        	}
		} else {
			sbf.append("kqdm不能为空;");
    		String msg = sbf.toString();
    		map.put("msg", msg);
    		return map;
		}
    	
    	/********遍历货位数据 start*********/

    	StringBuffer wsb = null;
    	JSONObject ware_obj = null;//货位字符串对象
    	Map<String, String> isadd_map = new HashMap<>();//标记每条货位是否是新增
    	BasicWarehouse warehouse = null;//货位实体对象数据

    	for (int j = 0; j < hwarray.size(); j++) {

    		wsb = new StringBuffer(100);
    		ware_obj = hwarray.getJSONObject(j);
 
    		warehouse = new BasicWarehouse();

    		//市平台货位唯一主键ID
    		String cfbh = ware_obj.getString("cfbh");
    		if (StringUtils.isNotBlank(cfbh)) {
    			BasicWarehouseExample example = new BasicWarehouseExample();
    			BasicWarehouseExample.Criteria criteria = example.createCriteria();
    			criteria.andSptDataidEqualTo(cfbh.trim());
    			List<BasicWarehouse> warecheck_list = wareMapper.selectByExample(example);
        		if (null != warecheck_list && warecheck_list.size() > 0) {//查到了，说明本次这条数据算是修改
        			isadd_map.put(cfbh.trim(), "false");//数据库里有这个id对应的数据，那就说明是修改
        			warehouse = warecheck_list.get(0);
        			if (storehouse.getStorehouseId() == null) {
        				storehouse.setStorehouseId(warehouse.getStorehouseId());
        			}
        		} else {//新增
        			isadd_map.put(cfbh.trim(), "true");
        			warehouse.setOrgId(orgId);
        			warehouse.setDepotId(orgId);
        			warehouse.setDepotName(orgName);
        			warehouse.setDelFlag(1);
        			warehouse.setCreatedate(new Date());
        			warehouse.setLibraryType("0");
        			warehouse.setCrkStatus("1");
        		}
        		warehouse.setSptDataid(cfbh.trim());
        	} else {
        		wsb.append("cfbh不能为空;");
        		break;
        	}

    		//货位代码
    		String hwdm = ware_obj.getString("hwdm");
    		if (StringUtils.isNotBlank(hwdm) && hwdm.trim().length() == 30) {
    			warehouse.setHwdm(hwdm);
    		} else {
    			wsb.append("hwdm不能为空且长度必须是30位;");
    		}

    		//货位名称
    		String hwmc = ware_obj.getString("cfmc");
    		if (StringUtils.isNotBlank(hwmc)) {
    			warehouse.setWarehouseName(hwmc.trim());
    		} else {
    			wsb.append("hwmc不能为空且长度必须是30位;");
    		}

    		//货位编号
    		String hwxh = ware_obj.getString("hwxh");
    		if (StringUtils.isNotBlank(hwxh) && hwxh.trim().length() == 2) {
    			//先判断是否编码重复,要在市平台仓房基础数据主键ID不为空的情况下判断
//    			if (StringUtils.isNotBlank(warehouse.getSptDataid()) && warehouse.getOrgId() != null && storehouse.getStorehouseId() != null) {
//    				BasicWarehouseExample example = new BasicWarehouseExample();
//    				BasicWarehouseExample.Criteria criteria = example.createCriteria();
//    				criteria.andOrgIdEqualTo(warehouse.getOrgId());
//    				criteria.andStorehouseIdEqualTo(storehouse.getStorehouseId());
//    				criteria.andWarehouseCodeEqualTo(hwxh);
//    				if ("false".equals(isadd_map.get(warehouse.getSptDataid()))) {//如果是修改，那么判断时要排除掉要修改的这条数据
//    					criteria.andSptDataidNotEqualTo(warehouse.getSptDataid());
//    				}
//    				List<BasicWarehouse> list = wareMapper.selectByExample(example);
//    				if (null != list && list.size() > 0) {
//    					wsb.append("hwxh货位编码重复了;");
//    				}
//    			}
    			warehouse.setWarehouseCode(hwxh.trim());
    		} else {
    			wsb.append("hwxh不能为空且长度必须是2位;");
    		}

    		//货位启用日期
    		String qyrq = ware_obj.getString("qyrq");
    		if (StringUtils.isNotBlank(qyrq)) {
    			warehouse.setWarehouseUseTime(ParameterUtil.string2date(qyrq.trim()));
    		} else {
    			wsb.append("qyrq不能为空且长度必须是30位;");
    		}

    		//货位容量
    		String hwrl = ware_obj.getString("hwrl");
    		if (StringUtils.isNotBlank(hwrl)) {
    			warehouse.setWarehouseCapacity(ParameterUtil.getBigDecimal(hwrl.trim(), 3));
    		}

    		//货位120编码
    		String cfbm = ware_obj.getString("cfbm");
    		if (StringUtils.isNotBlank(cfbm)) {
    			warehouse.setHwbm(cfbm.trim());
    		}
    		
    		String delflag = ware_obj.getString("status");
        	if (StringUtils.isNotBlank(delflag)) {
        		warehouse.setDelFlag(Integer.parseInt(delflag.trim()));
        	} else {
        		wsb.append("status货位的弃用状态不能为空;");
        	}
    		
    		if (wsb.toString().length() > 0) {
    			sbf.append("第").append(j+1).append("条货位数据中的").append(wsb);
    		}
    		
    		ware_list.add(warehouse);
    		   
    	}
    	/********遍历货位数据 end*********/

    	//仓房编号(三位的那个编号)
    	String cfxh = obj.getString("cfxh");
    	if (StringUtils.isNotBlank(cfxh)) {
    		//判断仓房数据是否需要新增,并且判断仓房编号是否重复
    		BasicStorehouseExample store_example = new BasicStorehouseExample();
    		BasicStorehouseExample.Criteria criteria = store_example.createCriteria();
    		criteria.andOrgIdEqualTo(orgId);
    		criteria.andStorehouseCodeEqualTo(cfxh.trim());
    		criteria.andDatatypeEqualTo("0");
    		if (null != storehouse.getStorehouseId()) {//说明当前仓房属于修改
    			
    			//先把当前仓房数据查询出来，后面在用数据串中的数据一个个的覆盖
    			storehouse = basic.selectByPrimaryKey(storehouse.getStorehouseId());
    			
    			//修改的情况下，校验过程不能包含当前这条数据
    			criteria.andStorehouseIdNotEqualTo(storehouse.getStorehouseId());
    		} else {
    			storehouse.setDelFlag(1);
    			storehouse.setLibraryType("0");
    			storehouse.setCreatedate(new Date());
    			storehouse.setUpdatedate(storehouse.getCreatedate());
    		}
    		List<BasicStorehouse> list = basic.selectByExample(store_example);
    		if (null != list && list.size() > 0) {
    			sbf.append("当前仓的仓房编号重复;");
    		}

    		storehouse.setStorehouseCode(cfxh.trim());
    	} else {
    		sbf.append("cfxh不能为空;");
    	}

    	//仓房标准编码
    	String cfbzbm = obj.getString("gfcfdm");
    	if (StringUtils.isNotBlank(cfbzbm) && cfbzbm.length() == 25) {
    		storehouse.setCfbm(cfbzbm.trim());
    	} else {
    		sbf.append("gfcfdm不能为空并且必须是25位;");
    	}

    	//仓房名称
    	String gfcfmc = obj.getString("gfcfmc");
    	if (StringUtils.isNotBlank(gfcfmc)) {
    		storehouse.setStorehouseName(gfcfmc.trim());
    	} else {
    		sbf.append("gfcfmc不能为空;");
    	}

    	//仓房类型
    	String cflxbh = obj.getString("cflx");
    	if (StringUtils.isNotBlank(cflxbh)) {
    		BasicEnum emm = basicEnumService.getBasicEnum(1064, cflxbh.trim());
    		if (null != emm) {
    			storehouse.setStorehouseType(emm.getEnumid());
    		} else {
    			sbf.append("cflxbh参数有误;");
    		}
    	} else {
    		sbf.append("cflxbh不能为空;");
    	}

    	//交付使用日期
    	String jfsyrq = obj.getString("jfsyrq");
    	if (StringUtils.isNotBlank(jfsyrq)) {
    		storehouse.setUsedate(ParameterUtil.string2date(jfsyrq));
    	}

    	//建设单位
    	String jsdw = obj.getString("jsdw");
    	if (StringUtils.isNotBlank(jsdw)) {
    		storehouse.setJsdw(jsdw.trim());
    	}

    	//设计使用年限
    	String sjnx = obj.getString("sjsynx");
    	if (StringUtils.isNotBlank(sjnx)) {
    		storehouse.setSjsynx(sjnx.trim());
    	}

    	//设计单位
    	String sjdw = obj.getString("sjdw");
    	if (StringUtils.isNotBlank(sjdw)) {
    		storehouse.setSjdw(sjdw.trim());
    	}

    	//监理单位
    	String jldw = obj.getString("jldw");
    	if (StringUtils.isNotBlank(jldw)) {
    		storehouse.setJldw(jldw.trim());
    	}

    	//仓房墙体结构
    	String qtjg = obj.getString("qtjg");
    	if (StringUtils.isNotBlank(qtjg)) {
    		BasicEnum emm = basicEnumService.getBasicEnum(7528, qtjg.trim());
    		if (null != emm) {
    			storehouse.setWall(emm.getEnumid());
    		} else {
    			sbf.append("qtjg参数有误;");
    		}
    	} else {
    		sbf.append("qtjg不能为空;");
    	}

    	//仓房房顶结构
    	String fdjg = obj.getString("fdjg");
    	if (StringUtils.isNotBlank(fdjg)) {
    		BasicEnum emm = basicEnumService.getBasicEnum(7529, fdjg.trim());
    		if (null != emm) {
    			storehouse.setRoof(emm.getEnumid().toString());
    		} else {
    			sbf.append("fdjg参数有误;");
    		}
    	} else {
    		sbf.append("fdjg不能为空;");
    	}
    	
    	//仓房房架结构
    	String fjjg = obj.getString("fjjg");
    	if (StringUtils.isNotBlank(fjjg)) {
    		BasicEnum emm = basicEnumService.getBasicEnum(7530, fjjg.trim());
    		if (null != emm) {
    			storehouse.setHouse(emm.getEnumid().toString());
    		} else {
    			sbf.append("fjjg参数有误;");
    		}
    	} else {
    		sbf.append("fjjg不能为空;");
    	}

    	//仓房地面结构
    	String dmjg = obj.getString("dmjg");
    	if (StringUtils.isNotBlank(dmjg)) {
    		BasicEnum emm = basicEnumService.getBasicEnum(7531, dmjg.trim());
    		if (null != emm) {
    			storehouse.setGround(emm.getEnumid().toString());
    		} else {
    			sbf.append("dmjg参数有误;");
    		}
    	} else {
    		sbf.append("dmjg不能为空;");
    	}

    	//实际仓容
    	String dczlrj = obj.getString("dczlrj");
    	if (StringUtils.isNotBlank(dczlrj)) {
    		storehouse.setActualCapacity(ParameterUtil.getBigDecimal(dczlrj.trim(), 4));
    	}

    	//设计仓容
    	String sjcr = obj.getString("sjcr");
    	if (StringUtils.isNotBlank(sjcr)) {
    		storehouse.setDesignCapacity(ParameterUtil.getBigDecimal(sjcr.trim(), 4));
    	} else {
    		sbf.append("sjcr不能为空;");
    	}

    	//仓外长
    	String cwc = obj.getString("cwc");
    	if (StringUtils.isNotBlank(cwc)) {
    		storehouse.setStoreOutsideLength(ParameterUtil.getBigDecimal(cwc.trim(), 2));
    	}

    	//仓外宽
    	String cwk = obj.getString("cwk");
    	if (StringUtils.isNotBlank(cwk)) {
    		storehouse.setStoreOutsideWidth(ParameterUtil.getBigDecimal(cwk.trim(), 2));
    	}

    	//仓外檐高
    	String cwyg = obj.getString("cwyg");
    	if (StringUtils.isNotBlank(cwyg)) {
    		storehouse.setStoreOutsideHeigth(ParameterUtil.getBigDecimal(cwyg.trim(), 2));
    	}

    	//仓外顶高
    	String cwdg = obj.getString("cwdg");
    	if (StringUtils.isNotBlank(cwdg)) {
    		storehouse.setStoreOutsideTopHeigth(ParameterUtil.getBigDecimal(cwdg.trim(), 2));
    	}

    	//筒仓外径
    	String cwtcwj = obj.getString("cwtcwj");
    	if (StringUtils.isNotBlank(cwtcwj)) {
    		storehouse.setOutsideSiloDiameter(ParameterUtil.getBigDecimal(cwtcwj.trim(), 2));
    	}

    	//仓内长
    	String cnc = obj.getString("cnc");
    	if (StringUtils.isNotBlank(cnc)) {
    		storehouse.setLength(ParameterUtil.getBigDecimal(cnc.trim(), 2));
    	}

    	//仓内宽
    	String cnk = obj.getString("cnk");
    	if (StringUtils.isNotBlank(cnk)) {
    		storehouse.setWidth(ParameterUtil.getBigDecimal(cnk.trim(), 2));
    	}

    	//仓内檐高
    	String cnyg = obj.getString("cnyg");
    	if (StringUtils.isNotBlank(cnyg)) {
    		storehouse.setHeigth(ParameterUtil.getBigDecimal(cnyg.trim(), 2));
    	}

    	//仓内装粮线高
    	String cnzlxg = obj.getString("cnzlxg");
    	if (StringUtils.isNotBlank(cnzlxg)) {
    		storehouse.setGrainLineHeigth(ParameterUtil.getBigDecimal(cnzlxg.trim(), 2));
    	}

    	//筒仓内径
    	String cntcnj = obj.getString("cntcnj");
    	if (StringUtils.isNotBlank(cntcnj)) {
    		storehouse.setSiloDiameter(ParameterUtil.getBigDecimal(cntcnj.trim(), 2));
    	}

    	//仓内体积
    	String cntj = obj.getString("cntj");
    	if (StringUtils.isNotBlank(cntj)) {
    		storehouse.setBinVolume(ParameterUtil.getBigDecimal(cntj.trim(), 2));
    	}

    	//仓门数量
    	String cmsl = obj.getString("cmsl");
    	if (StringUtils.isNotBlank(cmsl)) {
    		storehouse.setHouseDoorNum(Integer.parseInt(cmsl));
    	}

    	//挡粮门型式
    	String dlmxs = obj.getString("dlmxs");
    	if (StringUtils.isNotBlank(dlmxs)) {
    		storehouse.setDlmxs(dlmxs.trim());
    	}

    	//仓房是否完好
    	String cfsfwh = obj.getString("cfsfwh");
    	if (StringUtils.isNotBlank(cfsfwh)) {
    		if ("1".equals(cfsfwh)) {
    			storehouse.setStorehouseState(3011);
    		} else {
    			storehouse.setStorehouseState(3017);
    		}
    	} else {
    		sbf.append("cfsfwh不能为空;");
    	}

    	/***** start 遍历仓门信息 ******/
    	JSONObject cmobj = null;
    	String cmwz = null;
    	String cmgd = null;
    	String cmkd = null;
    	
    	cmobj = cmarray.getJSONObject(0);
//    	for (int i = 0; i < cmarray.size(); i++) {

//    		cmobj = cmarray.getJSONObject(i);

    		//仓门位置
    		cmwz = cmobj.getString("cmmc");
    		if (StringUtils.isNotBlank(cmwz)) {
    			storehouse.setHouseDootPosition(cmwz.trim());
    		}
    		
    		//仓门高度
    		cmgd = cmobj.getString("cmgd");
    		if (StringUtils.isNotBlank(cmgd)) {
    			storehouse.setHouseDoorHeigth(ParameterUtil.getBigDecimal(cmgd.trim(), 2));
    		}
    		
    		//仓门宽度
    		cmkd = cmobj.getString("cmkd");
    		if (StringUtils.isNotBlank(cmkd)) {
    			storehouse.setHouseDoorWidth(ParameterUtil.getBigDecimal(cmkd.trim(), 2));
    		}
//    	}
    	/***** end 遍历仓门信息 ******/

    	//储粮功效
    	String clgx = obj.getString("clgx");
    	if (StringUtils.isNotBlank(clgx)) {
    		storehouse.setClgx(Integer.parseInt(clgx.trim()));
    	} else {
    		sbf.append("clgx不能为空;");
    	}

    	//能否隔热保温
    	String nfgrbw = obj.getString("nfgrbw");
    	if (StringUtils.isNotBlank(nfgrbw)) {
    		storehouse.setNfgrbw(Integer.parseInt(nfgrbw.trim()));
    	} else {
    		sbf.append("nfgrbw不能为空;");
    	}

    	//隔热保温措施
    	String grbwcs = obj.getString("grbwcs");
    	if (StringUtils.isNotBlank(grbwcs)) {
    		storehouse.setGrbwcs(grbwcs.trim());
    	}

    	//隔热性能
    	String grxn = obj.getString("grxn");
    	if (StringUtils.isNotBlank(grxn)) {
    		storehouse.setGrxn(Integer.parseInt(grxn.trim()));
    	}

    	//结构材料
    	String jgcl = obj.getString("jgcl");
    	if (StringUtils.isNotBlank(jgcl)) {
    		storehouse.setJgcl(Integer.parseInt(jgcl.trim()));
    	} else {
    		sbf.append("jgcl不能为空;");
    	}

    	//气密性
    	String qmx = obj.getString("qmx");
    	if (StringUtils.isNotBlank(qmx)) {
    		storehouse.setQmx(Integer.parseInt(qmx.trim()));
    	}

    	//是否已进行信息化改造
    	String sfyjxxxhgz = obj.getString("sfyjxxxhgz");
    	if (StringUtils.isNotBlank(sfyjxxxhgz)) {
    		storehouse.setSfyjxxxhgz(Integer.parseInt(sfyjxxxhgz.trim()));
    	} else {
    		sbf.append("sfyjxxxhgz不能为空;");
    	}

    	//粮情技术
    	String lqjs = obj.getString("lqjs");
    	if (StringUtils.isNotBlank(lqjs)) {
    		storehouse.setLqjs(Integer.parseInt(lqjs.trim()));
    	} else {
    		sbf.append("lqjs不能为空;");
    	}

    	//能否散装储存
    	String sfszcc = obj.getString("sfszcc");
    	if (StringUtils.isNotBlank(sfszcc)) {
    		storehouse.setNfszcc(Integer.parseInt(sfszcc.trim()));
    	} else {
    		sbf.append("sfszcc不能为空;");
    	}

    	//有无防鼠防雀防虫装置及设施
    	String ywfsfqfczz = obj.getString("ywfsfqfczz");
    	if (StringUtils.isNotBlank(ywfsfqfczz)) {
    		storehouse.setYwfsfqfczz(Integer.parseInt(ywfsfqfczz.trim()));
    	} else {
    		sbf.append("ywfsfqfczz不能为空;");
    	}

    	//有无防火防爆防盗设施Y
    	String ywfhfbfdss = obj.getString("ywfhfbfdss");
    	if (StringUtils.isNotBlank(ywfhfbfdss)) {
    		storehouse.setYwfhfbfdss(Integer.parseInt(ywfhfbfdss.trim()));
    	} else {
    		sbf.append("ywfhfbfdss不能为空;");
    	}

    	//有无机械通风设施Y
    	String ywjxtfss = obj.getString("ywjxtfss");
    	if (StringUtils.isNotBlank(ywjxtfss)) {
    		storehouse.setYwjxtfss(Integer.parseInt(ywjxtfss.trim()));
    	} else {
    		sbf.append("ywjxtfss不能为空;");
    	}

    	//通风系统型式
    	String tfxtxs = obj.getString("tfxtxs");
    	if (StringUtils.isNotBlank(tfxtxs)) {
    		storehouse.setTfxtxs(Integer.parseInt(tfxtxs.trim()));
    	}

    	//通风技术Y
    	String tfjs = obj.getString("tfjs");
    	if (StringUtils.isNotBlank(tfjs)) {
    		storehouse.setTfjs(Integer.parseInt(tfjs.trim()));
    	} else {
    		sbf.append("tfjs不能为空;");
    	}

    	//能否环流熏蒸杀虫Y
    	String nfxlsc = obj.getString("nfxlsc");
    	if (StringUtils.isNotBlank(nfxlsc)) {
    		storehouse.setNfhlxzsc(Integer.parseInt(nfxlsc.trim()));
    	} else {
    		sbf.append("nfxlsc不能为空;");
    	}

    	//杀虫技术
    	String scjs = obj.getString("scjs");
    	if (StringUtils.isNotBlank(scjs)) {
    		storehouse.setScjs(Integer.parseInt(scjs.trim()));
    	}

    	//能否富氮低氧气调储粮Y
    	String nffddyqtcl = obj.getString("nffddyqtcl");
    	if (StringUtils.isNotBlank(nffddyqtcl)) {
    		storehouse.setNffddyqtcl(Integer.parseInt(nffddyqtcl.trim()));
    	} else {
    		sbf.append("nffddyqtcl不能为空;");
    	}

    	//控温技术
    	String kwjs = obj.getString("kwjs");
    	if (StringUtils.isNotBlank(kwjs)) {
    		storehouse.setKwjs(Integer.parseInt(kwjs.trim()));
    	}

    	//害虫检测方式Y
    	String hcjcfs = obj.getString("hcjcfs");
    	if (StringUtils.isNotBlank(hcjcfs)) {
    		storehouse.setHcjcfs(hcjcfs.trim());
    	} else {
    		sbf.append("hcjcfs不能为空;");
    	}

    	//仓房状态Y
    	String cfzt = obj.getString("cfzt");
    	if (StringUtils.isNotBlank(cfzt)) {
    		BasicEnum emm = basicEnumService.getBasicEnum(1001, cfzt.trim());
    		if (null != emm) {
    			storehouse.setStorehouseState(emm.getEnumid());
    		} else {
    			sbf.append("cfzt参数有误;");
    		}
    	} else {
    		sbf.append("cfzt不能为空;");
    	}
    	
    	//有无粮情检测设施
    	String ywlqckqk = obj.getString("ywlqckqk");
    	if (StringUtils.isNotBlank(ywlqckqk)) {
    		storehouse.setYwlqjcss(Integer.parseInt(ywlqckqk.trim()));
    	}
    	
    	//廒间标准编码
    	String ajdh = obj.getString("ajdh");
    	if (StringUtils.isNotBlank(ajdh) && ajdh.length() == 28) {
    		storehouse.setAjbm(ajdh.trim());
    	} else {
    		sbf.append("ajdh不能为空并且必须是28位;");
    	}
    	
//    	String delflag = obj.getString("status");
//    	if (StringUtils.isNotBlank(delflag)) {
//    		storehouse.setDelFlag(Integer.parseInt(delflag.trim()));
//    	} else {
//    		sbf.append("status仓房的弃用状态不能为空;");
//    	}

		String msg = sbf.toString();

		map.put("msg", msg);

		map.put("storehouse", storehouse);

		map.put("ware_list", ware_list);

		map.put("isadd_map", isadd_map);

		return map;
	}

}
