package com.chinaitop.depot.job.controller;

import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.job.model.ScheduleJob;
import com.chinaitop.depot.job.service.ScheduleJobService;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 定时任务
 * 
 * @author chenshun
 * @email sunlightcs@gmail.com
 * @date 2016年11月28日 下午2:16:40
 */
@RestController
@RequestMapping(value="/depot/basic/scheduleJob")
@Api(value= "ScheduleJobController", description = "定时任务控制类")
public class ScheduleJobController {
	@Autowired
	private ScheduleJobService scheduleJobService;
	
	/**
	 * 定时任务列表
	 */
	/*@RequestMapping("/list")
	public R list(@RequestParam Map<String, Object> params){
		//查询列表数据
		Query query = new Query(params);
		List<ScheduleJob> jobList = scheduleJobService.queryList(query);
		int total = scheduleJobService.queryTotal(query);
		
		PageUtils pageUtil = new PageUtils(jobList, total, query.getLimit(), query.getPage());
		
		return R.ok().put("page", pageUtil);
	}*/
	
    /**
     * 列表.
     * @param pageNum 页码
     * @param pageSize 每页显示条数
     * @return
     */
    @RequestMapping(value="/getList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询定时任务数据列表", notes = "查询定时任务数据列表，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
	})
    public PageInfo<ScheduleJob> getList(Integer pageNum, Integer pageSize, Integer orgId) {
        List<ScheduleJob> list = scheduleJobService.queryByExample(pageNum, pageSize, orgId);  
        PageInfo<ScheduleJob> pageInfo = new PageInfo<ScheduleJob>(list);
        return pageInfo;
    }
	
    /**
     * 根据主键id查询一条定时任务数据.
     * @param id 主键
     * @return
     */
    @RequestMapping(value="/edit", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据主键id查询一条定时任务数据", notes = "根据主键id查询一条定时任务数据")
    @ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "任务id", paramType = "query")
	})
    public Map<String, Object> edit(Long id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (id != null) {
            ScheduleJob scheduleJob = scheduleJobService.find(id);
            modelMap.put("scheduleJob", scheduleJob);
        }
        return modelMap;
    }
	
    /**
     * 更新一条定时任务
     * @param customerJson 业务数据json
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="更新一条定时任务", notes = "更新一条定时任务")
    @ApiImplicitParams({
		@ApiImplicitParam(name = "scheduleJobJson", value = "任务id", paramType = "form"),
		@ApiImplicitParam(name = "userInfo", value = "登录对象数据JSON", paramType = "form")
	})
    public Map<String, String> save(String scheduleJobJson, String userInfo) throws JsonParseException, JsonMappingException, IOException {
        Map<String, String> modelMap = new HashMap<String, String>();
        JSONObject user = JSONObject.parseObject(userInfo);
        Integer orgId = Integer.parseInt(user.get("orgId").toString());
        Integer userId = Integer.parseInt(user.get("userId").toString());
        try {
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            ScheduleJob scheduleJob = (ScheduleJob)mapper.readValue(scheduleJobJson, ScheduleJob.class);
            // 验证cron表达式的正确性.
            //ValidatorUtils.validateEntity(scheduleJob);
            if (scheduleJob.getId() == null) {
                modelMap = scheduleJobService.add(scheduleJob, orgId, userId);
            } else {
                modelMap = scheduleJobService.update(scheduleJob, userId);
            }
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
        return modelMap;
    }

   /**
     * 删除一条定时任务
     * 
     * @param id 主键
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value="/remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="删除一条定时任务", notes = "删除一条定时任务")
    @ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "任务id", paramType = "form")
	})
    public Map<String, Object> remove(Long id) throws JsonParseException, JsonMappingException, IOException {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (id != null) {
            scheduleJobService.remove(id);
        }
        modelMap.put("status", "success");
        return modelMap;
    }
	
	/**
	 * 立即执行任务
	 */
	@RequestMapping(value="/run", method = RequestMethod.GET)
	@ApiOperation(value="立即执行定时任务", notes = "立即执行定时任务")
    @ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "任务id", paramType = "query")
	})
	public Map<String, Object> run(Long id){
	    Map<String, Object> modelMap = new HashMap<String, Object>();
		scheduleJobService.run(id);
		modelMap.put("status", "success");
		return modelMap;
	}
	
	/**
	 * 暂停定时任务
	 */
	@RequestMapping(value="/pause", method = RequestMethod.GET)
	@ApiOperation(value="暂停定时任务", notes = "暂停定时任务")
    @ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "任务id", paramType = "query")
	})
	public Map<String, Object> pause(Long id){
	    Map<String, Object> modelMap = new HashMap<String, Object>();
		scheduleJobService.pause(id);
		modelMap.put("status", "success");
		return modelMap;
	}
	
	/**
	 * 恢复定时任务
	 */
	@RequestMapping(value="/resume", method = RequestMethod.GET)
	@ApiOperation(value="恢复定时任务", notes = "恢复定时任务")
    @ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "任务id", paramType = "query")
	})
	public Map<String, Object> resume(Long id){
	    Map<String, Object> modelMap = new HashMap<String, Object>();
		scheduleJobService.resume(id);
		modelMap.put("status", "success");
		return modelMap;
	}

}
