package com.chinaitop.depot.unissoft.webservice;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSONArray;
import com.chinaitop.depot.Object.HwObj;
import com.chinaitop.depot.Object.YwConstant;
import com.chinaitop.depot.basic.mapper.BasicStorehouseMapper;
import com.chinaitop.depot.basic.mapper.BasicTankHwMapper;
import com.chinaitop.depot.basic.mapper.BasicTankMapper;
import com.chinaitop.depot.basic.mapper.BasicWarehouseMapper;
import com.chinaitop.depot.basic.model.BasicStorehouse;
import com.chinaitop.depot.basic.model.BasicTank;
import com.chinaitop.depot.basic.model.BasicTankHw;
import com.chinaitop.depot.basic.model.BasicWarehouse;
import com.chinaitop.depot.basic.service.BasicWarehouseService;
import com.chinaitop.utils.ParameterUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;

@Service
public class BasicWarehouseWebServiceImpl implements BasicWarehouseWebService {

	final static Logger logger = LoggerFactory.getLogger(BasicWarehouse.class);

	@Resource
	private BasicStorehouseMapper storehouseMapper;
	
	@Resource
	private BasicWarehouseMapper warehouseMapper;

	@Resource
	private BasicWarehouseService basicWarehouseService;

	@Resource
	private BasicTankMapper tankMapper;

	@Resource
	private BasicTankHwMapper tankHwMapper;

	@Override
	@SuppressWarnings("all")
	public String uploadCfStatus(String json) {
		Map<String, Object> result = new HashMap<String, Object>();

		String date = ParameterUtil.getSysDateTime();
		logger.info("时间："+date+"，出入库状态回写接口，出入库系统调用，接收参数是："+json);
		try {
			if (StringUtils.isNotEmpty(json)) {
				/* 将获取到的json串转换成HwObj集合 */
				json = json.replace("chId", "houseId")
						.replace("hwId", "wareId")
						.replace("org_Id", "orgId");
				ObjectMapper objectMapper = new ObjectMapper();
				List<HwObj> hwObjs = objectMapper.readValue(json, new TypeReference<List<HwObj>>() {
				});

				/* 遍历hwObjs集合，获取集合中值 */
				hwObjs.forEach(obj->{
					//如果仓房ID跟货位ID一样那么说明这个数据是属于油罐的，否则就是仓房下的货位
					BasicStorehouse storeh = storehouseMapper.selectByPrimaryKey(Integer.parseInt(obj.getHouseId()));
					if (YwConstant.YW_LX_YG.equals(storeh.getDatatype())) {//油罐数据
						BasicTank basicTank = tankMapper.selectByPrimaryKey(obj.getWareId());
						//当前油罐只要不是放着成品油那就允许修改
						//粮油类型(0:原粮,1:成品粮)
						if (StringUtils.isBlank(basicTank.getLylx()) || YwConstant.LY_LX_YL.equals(basicTank.getLylx())) {
							Map<String, Object> param = new HashMap<>();
							param.put("houseId", Integer.parseInt(basicTank.getId()));
							param.put("orgId", Integer.parseInt(obj.getOrgId()));
							param.put("status", obj.getStatus());
							if (null != basicTank && YwConstant.FC_STATUS.equals(basicTank.getCrkStatus())) {
								/**
								 * 查询封仓时间，看业务时间是不是在分仓时间之后。
								 * 要是在分仓时间之前，那就不许修改。
								 * 说明这是因为别的原因当时没刷，后面补刷推过来的数据
								 */
								List<Map<String, Object>> lqk_map = warehouseMapper.queryFenCangCfData(param);
								if (null != lqk_map && lqk_map.size() > 0) {//说明有封仓数据
									String fcsj = lqk_map.get(0).get("accept_date")+"";
									//判断封仓时间在不在业务时间之前,要是在分仓时间之前，那就不许修改
									if (ParameterUtil.string2datetime(fcsj).after(ParameterUtil.string2datetime(obj.getCjsj()))) {
										//continue;
									} else {//业务时间在封仓时间之后，要修改状态
										//回写油罐的出入库状态
										this.updateTankCrkStatus(param, basicTank);
									}
								}
							} else {
								//回写油罐的出入库状态
								this.updateTankCrkStatus(param, basicTank);
							}

						}
					} else if (YwConstant.YW_LX_LC.equals(storeh.getDatatype())) {//粮仓
						//查询当前货位信息
						BasicWarehouse warehouse = warehouseMapper.selectByPrimaryKey(Integer.parseInt(obj.getWareId()));
						if (null != warehouse) {
							//当前粮仓只要不是放着成品油那就允许修改
							//粮油类型(0:原粮,1:成品粮)
							if (StringUtils.isBlank(warehouse.getLylx()) || YwConstant.LY_LX_YL.equals(warehouse.getLylx())) {
								Map<String, Object> param = new HashMap<>();
								param.put("houseId", warehouse.getStorehouseId());
								param.put("wareId", Integer.parseInt(obj.getWareId()));
								param.put("orgId", Integer.parseInt(obj.getOrgId()));
								param.put("status", obj.getStatus());
								if ("3".equals(warehouse.getCrkStatus())) {
									//查询封仓时间
									List<Map<String, Object>> lqk_map = warehouseMapper.queryFenCangCfData(param);
									if (null != lqk_map && lqk_map.size() > 0) {
										String fcsj = lqk_map.get(0).get("accept_date")+"";
										//判断封仓时间在不在业务时间之前，在业务时间之前，就刷新状态，不在，那就说明是老业务的，当前货位状态不用刷新
										if (ParameterUtil.string2datetime(fcsj).after(ParameterUtil.string2datetime(obj.getCjsj()))) {
											//continue;
										} else {
											//回写状态
											this.updateWareCrkStatus(param);
										}
									} else {//没查到封仓数据，那也不刷新，都没封仓数据，你封个什么仓
										//this.updateWareCrkStatus(param);
									}
								} else {
									//回写状态
									this.updateWareCrkStatus(param);
								}
							}
						}
					}
				});
			}
			result.put("success", "true");
			result.put("msg", "上传成功");
			logger.info("时间："+date+"，出入库状态回写接口，出入库系统调用，调用成功！");
		} catch (NumberFormatException e) {
			logger.info("时间："+date+"，出入库状态回写接口，出入库系统调用，调用失败！");
			logger.error(e.getMessage(), e);
			//e.printStackTrace();
			result.put("success", "false");
			result.put("msg", "上传失败");
		} finally {
			JSONArray jsonArray = new JSONArray();
			jsonArray.add(result);
			return jsonArray.toString();
		}
	}

	/**
	 * 原粮修改出入库状态
	 * @param param
	 */
	private void updateWareCrkStatus(Map<String, Object> param) {
		String status = param.get("status").toString();
		BasicWarehouse ware = new BasicWarehouse();
		ware.setWarehouseId(Integer.parseInt(param.get("wareId").toString()));
		ware.setCrkStatus(status);
		if ("1".equals(status)) {//空仓
			ware.setLylx("");
		} else {
			ware.setLylx("0");
		}
		ware.setUpdatetime(new Date());
		warehouseMapper.updateByPrimaryKeySelective(ware);

		if (!"3".equals(status)) {
			Map<String, Object> lqkmap = new HashMap<String, Object>();
			lqkmap.put("wareId", param.get("wareId"));
			lqkmap.put("orgId", param.get("orgId"));
			int count = warehouseMapper.updateYlLqkGd(lqkmap);//归档原粮粮情卡
			if (count > 0) {//有粮情卡被归档了，质检在归档，没有就不归档了
				warehouseMapper.updateQualitycheck(lqkmap);//归档自检数据
			}
		}
	}

	/**
	 * 修改油罐的出入库状态
	 * @param param
	 * @param basicTank 
	 */
	private void updateTankCrkStatus(Map<String, Object> param, BasicTank basicTank) {
		String status = param.get("status").toString();
		Integer wareId = Integer.parseInt(basicTank.getId());
		basicTank.setCrkStatus(status);
		basicTank.setUpdatetime(new Date());
		if ("1".equals(status)) {//空仓
			basicTank.setLylx("");
		} else {//入库
			basicTank.setLylx("0");
		}
		tankMapper.updateByPrimaryKey(basicTank);
		BasicTankHw tankHw = new BasicTankHw();
		tankHw.setId(wareId);
		tankHw.setCrkStatus(status);
		tankHw.setZhgxsj(new Date());
		tankHwMapper.updateByPrimaryKeySelective(tankHw);
		//如果是出库，则把对应的粮情卡设置为归档
		if (!"3".equals(status)) {//出库、入库或者空仓
			Map<String, Object> lqkmap = new HashMap<String, Object>();
			lqkmap.put("storehouseId", wareId);
			lqkmap.put("orgId", param.get("orgId"));
			int count = warehouseMapper.updateYlLqkGd(lqkmap);//归档原粮粮情卡
			if (count > 0) {
				warehouseMapper.updateQualitycheck(lqkmap);//归档自检数据
			}
		}
	}

}
